import React, { useMemo, useState, useCallback, Fragment, useLayoutEffect, useEffect } from 'react';
import ArrowRightIcon from '@mui/icons-material/ArrowRight';
import CancelIcon from '@mui/icons-material/Cancel';
import CheckBoxIcon from '@mui/icons-material/CheckBox';
import ClearAllIcon from '@mui/icons-material/ClearAll';
import CloseIcon from '@mui/icons-material/Close';
import DensityMediumIcon from '@mui/icons-material/DensityMedium';
import DensitySmallIcon from '@mui/icons-material/DensitySmall';
import DoubleArrowDownIcon from '@mui/icons-material/KeyboardDoubleArrowDown';
import DynamicFeedIcon from '@mui/icons-material/DynamicFeed';
import EditIcon from '@mui/icons-material/Edit';
import ExpandLessIcon from '@mui/icons-material/ExpandLess';
import ExpandMoreIcon from '@mui/icons-material/ExpandMore';
import FilterAltIcon from '@mui/icons-material/FilterAlt';
import FilterAltOff from '@mui/icons-material/FilterAltOff';
import FilterListIcon from '@mui/icons-material/FilterList';
import FilterListOffIcon from '@mui/icons-material/FilterListOff';
import FullscreenExitIcon from '@mui/icons-material/FullscreenExit';
import FullscreenIcon from '@mui/icons-material/Fullscreen';
import MoreHorizIcon from '@mui/icons-material/MoreHoriz';
import MoreVertIcon from '@mui/icons-material/MoreVert';
import PushPinIcon from '@mui/icons-material/PushPin';
import SaveIcon from '@mui/icons-material/Save';
import SearchIcon from '@mui/icons-material/Search';
import SearchOffIcon from '@mui/icons-material/SearchOff';
import SortIcon from '@mui/icons-material/Sort';
import ViewColumnIcon from '@mui/icons-material/ViewColumn';
import VisibilityOffIcon from '@mui/icons-material/VisibilityOff';
import { createTable, useTable, columnFilterRowsFn, expandRowsFn, globalFilterRowsFn, groupRowsFn, functionalUpdate, paginateRowsFn, sortRowsFn } from '@tanstack/react-table';
import { IconButton, Menu, MenuItem, FormControlLabel, Switch, Box, Button, Divider, ListItemIcon, Tooltip, Checkbox, debounce, Collapse, TextField, InputAdornment, TablePagination, useMediaQuery, Chip, Alert, LinearProgress, Toolbar, alpha, TableCell, TableSortLabel, TableRow, TableHead, Skeleton, TableBody, TableFooter, Table, TableContainer, Paper } from '@mui/material';
import { matchSorter } from 'match-sorter';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var MRT_DefaultLocalization_EN = {
  actions: 'Actions',
  cancel: 'Cancel',
  changeFilterMode: 'Change filter mode',
  changeSearchMode: 'Change search mode',
  clearFilter: 'Clear filter',
  clearSearch: 'Clear search',
  clearSort: 'Clear sort',
  clickToCopy: 'Click to copy',
  columnActions: 'Column Actions',
  copiedToClipboard: 'Copied to clipboard',
  edit: 'Edit',
  expand: 'Expand',
  expandAll: 'Expand all',
  filterBestMatch: 'Best Match',
  filterBestMatchFirst: 'Best Match First',
  filterByColumn: 'Filter by {column}',
  filterContains: 'Contains',
  filterEmpty: 'Empty',
  filterEndsWith: 'Ends With',
  filterEquals: 'Equals',
  filterGreaterThan: 'Greater Than',
  filterLessThan: 'Less Than',
  filterMode: 'Filter Mode: {filterType}',
  filterNotEmpty: 'Not Empty',
  filterNotEquals: 'Not Equals',
  filterStartsWith: 'Starts With',
  filteringByColumn: 'Filtering by {column} - {filterType} "{filterValue}"',
  groupByColumn: 'Group by {column}',
  groupedBy: 'Grouped by ',
  hideAll: 'Hide all',
  hideColumn: 'Hide {column} column',
  pinToLeft: 'Pin to left',
  pinToRight: 'Pin to right',
  rowActions: 'Row Actions',
  rowNumbers: 'Row Numbers',
  save: 'Save',
  search: 'Search',
  selectedCountOfRowCountRowsSelected: '{selectedCount} of {rowCount} row(s) selected',
  select: 'Select',
  showAll: 'Show all',
  showAllColumns: 'Show all columns',
  showHideColumns: 'Show/Hide columns',
  showHideFilters: 'Show/Hide filters',
  showHideSearch: 'Show/Hide search',
  sortByColumnAsc: 'Sort by {column} ascending',
  sortByColumnDesc: 'Sort by {column} descending',
  thenBy: ', then by ',
  toggleDensePadding: 'Toggle dense padding',
  toggleFullScreen: 'Toggle full screen',
  toggleSelectAll: 'Toggle select all',
  toggleSelectRow: 'Toggle select row',
  ungroupByColumn: 'Ungroup by {column}',
  unpin: 'Unpin'
};

var MRT_Default_Icons = {
  ArrowRightIcon: ArrowRightIcon,
  CancelIcon: CancelIcon,
  CheckBoxIcon: CheckBoxIcon,
  ClearAllIcon: ClearAllIcon,
  CloseIcon: CloseIcon,
  DensityMediumIcon: DensityMediumIcon,
  DensitySmallIcon: DensitySmallIcon,
  DoubleArrowDownIcon: DoubleArrowDownIcon,
  DynamicFeedIcon: DynamicFeedIcon,
  EditIcon: EditIcon,
  ExpandLessIcon: ExpandLessIcon,
  ExpandMoreIcon: ExpandMoreIcon,
  FilterAltIcon: FilterAltIcon,
  FilterAltOff: FilterAltOff,
  FilterListIcon: FilterListIcon,
  FilterListOffIcon: FilterListOffIcon,
  FullscreenExitIcon: FullscreenExitIcon,
  FullscreenIcon: FullscreenIcon,
  MoreHorizIcon: MoreHorizIcon,
  MoreVertIcon: MoreVertIcon,
  PushPinIcon: PushPinIcon,
  SaveIcon: SaveIcon,
  SearchIcon: SearchIcon,
  SearchOffIcon: SearchOffIcon,
  SortIcon: SortIcon,
  ViewColumnIcon: ViewColumnIcon,
  VisibilityOffIcon: VisibilityOffIcon
};

var MRT_ExpandAllButton = function MRT_ExpandAllButton(_ref) {
  var tableInstance = _ref.tableInstance;
  var getIsAllRowsExpanded = tableInstance.getIsAllRowsExpanded,
      getIsSomeRowsExpanded = tableInstance.getIsSomeRowsExpanded,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      DoubleArrowDownIcon = _tableInstance$option.icons.DoubleArrowDownIcon,
      isLoading = _tableInstance$option.isLoading,
      localization = _tableInstance$option.localization,
      toggleAllRowsExpanded = tableInstance.toggleAllRowsExpanded;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React.createElement(IconButton, {
    "aria-label": localization.expandAll,
    disabled: isLoading,
    title: localization.expandAll,
    onClick: function onClick() {
      return toggleAllRowsExpanded(!getIsAllRowsExpanded());
    },
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React.createElement(DoubleArrowDownIcon, {
    style: {
      transform: "rotate(" + (getIsAllRowsExpanded() ? -180 : getIsSomeRowsExpanded() ? -90 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  }));
};

var MRT_ExpandButton = function MRT_ExpandButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      ExpandMoreIcon = _tableInstance$option.icons.ExpandMoreIcon,
      localization = _tableInstance$option.localization,
      onRowExpandChange = _tableInstance$option.onRowExpandChange,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleToggleExpand = function handleToggleExpand(event) {
    row.toggleExpanded();
    onRowExpandChange == null ? void 0 : onRowExpandChange({
      event: event,
      row: row,
      tableInstance: tableInstance
    });
  };

  return React.createElement(IconButton, {
    "aria-label": localization.expand,
    disabled: !row.getCanExpand() && !renderDetailPanel,
    title: localization.expand,
    onClick: handleToggleExpand,
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    }
  }, React.createElement(ExpandMoreIcon, {
    style: {
      transform: "rotate(" + (!row.getCanExpand() && !renderDetailPanel ? -90 : row.getIsExpanded() ? -180 : 0) + "deg)",
      transition: 'transform 0.2s'
    }
  }));
};

var MRT_FILTER_TYPE;

(function (MRT_FILTER_TYPE) {
  MRT_FILTER_TYPE["BEST_MATCH"] = "bestMatch";
  MRT_FILTER_TYPE["BEST_MATCH_FIRST"] = "bestMatchFirst";
  MRT_FILTER_TYPE["CONTAINS"] = "contains";
  MRT_FILTER_TYPE["EMPTY"] = "empty";
  MRT_FILTER_TYPE["ENDS_WITH"] = "endsWith";
  MRT_FILTER_TYPE["EQUALS"] = "equals";
  MRT_FILTER_TYPE["GREATER_THAN"] = "greaterThan";
  MRT_FILTER_TYPE["LESS_THAN"] = "lessThan";
  MRT_FILTER_TYPE["NOT_EMPTY"] = "notEmpty";
  MRT_FILTER_TYPE["NOT_EQUALS"] = "notEquals";
  MRT_FILTER_TYPE["STARTS_WITH"] = "startsWith";
})(MRT_FILTER_TYPE || (MRT_FILTER_TYPE = {}));

var bestMatchFirst = function bestMatchFirst(rows, columnIds, filterValue) {
  return matchSorter(rows, filterValue.toString().trim(), {
    keys: Array.isArray(columnIds) ? columnIds.map(function (c) {
      return "values." + c;
    }) : ["values." + columnIds]
  });
};

bestMatchFirst.autoRemove = function (val) {
  return !val;
};

var bestMatch = function bestMatch(rows, columnIds, filterValue) {
  return matchSorter(rows, filterValue.toString().trim(), {
    keys: Array.isArray(columnIds) ? columnIds.map(function (c) {
      return "values." + c;
    }) : ["values." + columnIds],
    sorter: function sorter(rankedItems) {
      return rankedItems;
    }
  });
};

bestMatch.autoRemove = function (val) {
  return !val;
};

var contains = function contains(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().includes(filterValue.toString().toLowerCase().trim());
  });
};

contains.autoRemove = function (val) {
  return !val;
};

var startsWith = function startsWith(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().startsWith(filterValue.toString().toLowerCase().trim());
  });
};

startsWith.autoRemove = function (val) {
  return !val;
};

var endsWith = function endsWith(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim().endsWith(filterValue.toString().toLowerCase().trim());
  });
};

endsWith.autoRemove = function (val) {
  return !val;
};

var equals = function equals(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim() === filterValue.toString().toLowerCase().trim();
  });
};

equals.autoRemove = function (val) {
  return !val;
};

var notEquals = function notEquals(rows, id, filterValue) {
  return rows.filter(function (row) {
    return row.values[id].toString().toLowerCase().trim() !== filterValue.toString().toLowerCase().trim();
  });
};

notEquals.autoRemove = function (val) {
  return !val;
};

var greaterThan = function greaterThan(rows, id, filterValue) {
  return rows.filter(function (row) {
    return !isNaN(+filterValue) && !isNaN(+row.values[id]) ? +row.values[id] > +filterValue : row.values[id].toString().toLowerCase().trim() > filterValue.toString().toLowerCase().trim();
  });
};

greaterThan.autoRemove = function (val) {
  return !val;
};

var lessThan = function lessThan(rows, id, filterValue) {
  return rows.filter(function (row) {
    return !isNaN(+filterValue) && !isNaN(+row.values[id]) ? +row.values[id] < +filterValue : row.values[id].toString().toLowerCase().trim() < filterValue.toString().toLowerCase().trim();
  });
};

lessThan.autoRemove = function (val) {
  return !val;
};

var empty = function empty(rows, id, _filterValue) {
  return rows.filter(function (row) {
    return !row.values[id].toString().toLowerCase().trim();
  });
};

empty.autoRemove = function (val) {
  return !val;
};

var notEmpty = function notEmpty(rows, id, _filterValue) {
  return rows.filter(function (row) {
    return !!row.values[id].toString().toLowerCase().trim();
  });
};

notEmpty.autoRemove = function (val) {
  return !val;
};

var defaultFilterFNs = {
  bestMatch: bestMatch,
  bestMatchFirst: bestMatchFirst,
  contains: contains,
  empty: empty,
  endsWith: endsWith,
  equals: equals,
  greaterThan: greaterThan,
  lessThan: lessThan,
  notEmpty: notEmpty,
  notEquals: notEquals,
  startsWith: startsWith
};

var commonMenuItemStyles = {
  py: '6px',
  my: 0,
  alignItems: 'center'
};
var MRT_FilterTypeMenu = function MRT_FilterTypeMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      onSelect = _ref.onSelect,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enabledGlobalFilterTypes = _tableInstance$option.enabledGlobalFilterTypes,
      localization = _tableInstance$option.localization,
      setCurrentFilterTypes = _tableInstance$option.setCurrentFilterTypes,
      setCurrentGlobalFilterType = _tableInstance$option.setCurrentGlobalFilterType;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      currentFilterTypes = _getState.currentFilterTypes,
      currentGlobalFilterType = _getState.currentGlobalFilterType;

  var filterTypes = useMemo(function () {
    return [{
      type: MRT_FILTER_TYPE.BEST_MATCH_FIRST,
      label: localization.filterBestMatchFirst,
      divider: false,
      fn: bestMatchFirst
    }, {
      type: MRT_FILTER_TYPE.BEST_MATCH,
      label: localization.filterBestMatch,
      divider: !!header,
      fn: bestMatch
    }, {
      type: MRT_FILTER_TYPE.CONTAINS,
      label: localization.filterContains,
      divider: false,
      fn: contains
    }, {
      type: MRT_FILTER_TYPE.STARTS_WITH,
      label: localization.filterStartsWith,
      divider: false,
      fn: startsWith
    }, {
      type: MRT_FILTER_TYPE.ENDS_WITH,
      label: localization.filterEndsWith,
      divider: true,
      fn: endsWith
    }, {
      type: MRT_FILTER_TYPE.EQUALS,
      label: localization.filterEquals,
      divider: false,
      fn: equals
    }, {
      type: MRT_FILTER_TYPE.NOT_EQUALS,
      label: localization.filterNotEquals,
      divider: true,
      fn: notEquals
    }, {
      type: MRT_FILTER_TYPE.GREATER_THAN,
      label: localization.filterGreaterThan,
      divider: false,
      fn: greaterThan
    }, {
      type: MRT_FILTER_TYPE.LESS_THAN,
      label: localization.filterLessThan,
      divider: true,
      fn: lessThan
    }, {
      type: MRT_FILTER_TYPE.EMPTY,
      label: localization.filterEmpty,
      divider: false,
      fn: empty
    }, {
      type: MRT_FILTER_TYPE.NOT_EMPTY,
      label: localization.filterNotEmpty,
      divider: false,
      fn: notEmpty
    }].filter(function (filterType) {
      return header ? !header.column.enabledFilterTypes || header.column.enabledFilterTypes.includes(filterType.type) : (!enabledGlobalFilterTypes || enabledGlobalFilterTypes.includes(filterType.type)) && [MRT_FILTER_TYPE.BEST_MATCH_FIRST, MRT_FILTER_TYPE.BEST_MATCH].includes(filterType.type);
    });
  }, []);

  var handleSelectFilterType = function handleSelectFilterType(value) {
    if (header) {
      setCurrentFilterTypes(function (prev) {
        var _extends2;

        return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = value, _extends2));
      });

      if ([MRT_FILTER_TYPE.EMPTY, MRT_FILTER_TYPE.NOT_EMPTY].includes(value)) {
        header.column.setColumnFilterValue(' ');
      }
    } else {
      setCurrentGlobalFilterType(value);
    }

    setAnchorEl(null);
    onSelect == null ? void 0 : onSelect();
  };

  var filterType = !!header ? currentFilterTypes[header.id] : currentGlobalFilterType;
  return React.createElement(Menu, {
    anchorEl: anchorEl,
    anchorOrigin: {
      vertical: 'center',
      horizontal: 'right'
    },
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    open: !!anchorEl,
    MenuListProps: {
      dense: isDensePadding
    }
  }, filterTypes.map(function (_ref2, index) {
    var type = _ref2.type,
        label = _ref2.label,
        divider = _ref2.divider,
        fn = _ref2.fn;
    return React.createElement(MenuItem, {
      divider: divider,
      key: index,
      onClick: function onClick() {
        return handleSelectFilterType(type);
      },
      selected: type === filterType || fn === filterType,
      sx: commonMenuItemStyles,
      value: type
    }, label);
  }));
};

var MRT_ShowHideColumnsMenuItems = function MRT_ShowHideColumnsMenuItems(_ref) {
  var _column$columns2;

  var column = _ref.column,
      isSubMenu = _ref.isSubMenu,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      onColumnHide = tableInstance.options.onColumnHide;

  var _getState = getState(),
      columnVisibility = _getState.columnVisibility;

  var switchChecked = column.columnDefType !== 'group' && column.getIsVisible() || column.columnDefType === 'group' && column.getLeafColumns().some(function (col) {
    return col.getIsVisible();
  });

  var handleToggleColumnHidden = function handleToggleColumnHidden(column) {
    if (column.columnDefType === 'group') {
      var _column$columns;

      column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.forEach == null ? void 0 : _column$columns.forEach(function (childColumn) {
        childColumn.toggleVisibility(!switchChecked);
      });
    } else {
      column.toggleVisibility();
    }

    onColumnHide == null ? void 0 : onColumnHide({
      column: column,
      columnVisibility: columnVisibility,
      tableInstance: tableInstance
    });
  };

  return React.createElement(React.Fragment, null, React.createElement(MenuItem, {
    sx: _extends({}, commonMenuItemStyles$1, {
      pl: (column.depth + 0.5) * 2 + "rem"
    })
  }, React.createElement(FormControlLabel, {
    componentsProps: {
      typography: {
        sx: {
          marginBottom: 0
        }
      }
    },
    checked: switchChecked,
    control: React.createElement(Switch, null),
    disabled: isSubMenu && switchChecked || column.enableHiding === false,
    label: column.header,
    onChange: function onChange() {
      return handleToggleColumnHidden(column);
    }
  })), (_column$columns2 = column.columns) == null ? void 0 : _column$columns2.map(function (c, i) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      key: i + "-" + c.id,
      column: c,
      isSubMenu: isSubMenu,
      tableInstance: tableInstance
    });
  }));
};

var MRT_ShowHideColumnsMenu = function MRT_ShowHideColumnsMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      isSubMenu = _ref.isSubMenu,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getAllColumns = tableInstance.getAllColumns,
      getIsAllColumnsVisible = tableInstance.getIsAllColumnsVisible,
      getIsSomeColumnsVisible = tableInstance.getIsSomeColumnsVisible,
      getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      getAllLeafColumns = tableInstance.getAllLeafColumns,
      localization = tableInstance.options.localization;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var hideAllColumns = function hideAllColumns() {
    getAllLeafColumns().filter(function (col) {
      return col.enableHiding !== false;
    }).forEach(function (col) {
      return col.toggleVisibility(false);
    });
  };

  var allDisplayColumns = useMemo(function () {
    return getAllColumns().filter(function (col) {
      return col.columnDefType === 'display';
    });
  }, [getAllColumns()]);
  var allDataColumns = useMemo(function () {
    var dataColumns = getAllColumns().filter(function (col) {
      return col.columnDefType !== 'display';
    });
    return getIsSomeColumnsPinned() ? [].concat(dataColumns.filter(function (c) {
      return c.getIsPinned() === 'left';
    }), dataColumns.filter(function (c) {
      return c.getIsPinned() === false;
    }), dataColumns.filter(function (c) {
      return c.getIsPinned() === 'right';
    })) : dataColumns;
  }, [getAllColumns(), getState().columnPinning, getIsSomeColumnsPinned()]);
  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: isSubMenu ? 'center' : 'space-between',
      p: '0.5rem',
      pt: 0
    }
  }, !isSubMenu && React.createElement(Button, {
    disabled: !getIsSomeColumnsVisible(),
    onClick: hideAllColumns
  }, localization.hideAll), React.createElement(Button, {
    disabled: getIsAllColumnsVisible(),
    onClick: function onClick() {
      return toggleAllColumnsVisible(true);
    }
  }, localization.showAll)), React.createElement(Divider, null), allDisplayColumns.map(function (column, index) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      column: column,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id,
      tableInstance: tableInstance
    });
  }), React.createElement(Divider, null), allDataColumns.map(function (column, index) {
    return React.createElement(MRT_ShowHideColumnsMenuItems, {
      column: column,
      isSubMenu: isSubMenu,
      key: index + "-" + column.id,
      tableInstance: tableInstance
    });
  }));
};

var commonMenuItemStyles$1 = {
  py: '6px',
  my: 0,
  justifyContent: 'space-between',
  alignItems: 'center'
};
var commonListItemStyles = {
  display: 'flex',
  alignItems: 'center'
};
var MRT_ColumnActionMenu = function MRT_ColumnActionMenu(_ref) {
  var _localization$sortByC, _localization$sortByC2, _localization$filterB, _localization, _localization$hideCol, _localization$showAll;

  var anchorEl = _ref.anchorEl,
      header = _ref.header,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      toggleAllColumnsVisible = tableInstance.toggleAllColumnsVisible,
      setColumnOrder = tableInstance.setColumnOrder,
      _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnPinning = _tableInstance$option.enableColumnPinning,
      enableGrouping = _tableInstance$option.enableGrouping,
      enableHiding = _tableInstance$option.enableHiding,
      enableSorting = _tableInstance$option.enableSorting,
      _tableInstance$option2 = _tableInstance$option.icons,
      ArrowRightIcon = _tableInstance$option2.ArrowRightIcon,
      ClearAllIcon = _tableInstance$option2.ClearAllIcon,
      ViewColumnIcon = _tableInstance$option2.ViewColumnIcon,
      DynamicFeedIcon = _tableInstance$option2.DynamicFeedIcon,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      PushPinIcon = _tableInstance$option2.PushPinIcon,
      SortIcon = _tableInstance$option2.SortIcon,
      VisibilityOffIcon = _tableInstance$option2.VisibilityOffIcon,
      idPrefix = _tableInstance$option.idPrefix,
      localization = _tableInstance$option.localization,
      setShowFilters = _tableInstance$option.setShowFilters;
  var column = header.column;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      columnVisibility = _getState.columnVisibility;

  var _useState = useState(null),
      filterMenuAnchorEl = _useState[0],
      setFilterMenuAnchorEl = _useState[1];

  var _useState2 = useState(null),
      showHideColumnsMenuAnchorEl = _useState2[0],
      setShowHideColumnsMenuAnchorEl = _useState2[1];

  var handleClearSort = function handleClearSort() {
    column.resetSorting();
    setAnchorEl(null);
  };

  var handleSortAsc = function handleSortAsc() {
    column.toggleSorting(false);
    setAnchorEl(null);
  };

  var handleSortDesc = function handleSortDesc() {
    column.toggleSorting(true);
    setAnchorEl(null);
  };

  var handleHideColumn = function handleHideColumn() {
    column.toggleVisibility(false);
    setAnchorEl(null);
  };

  var handlePinColumn = function handlePinColumn(pinDirection) {
    column.pin(pinDirection);
  };

  var handleGroupByColumn = function handleGroupByColumn() {
    column.toggleGrouping();
    setColumnOrder(function (old) {
      return ['mrt-expand'].concat(old);
    });
    setAnchorEl(null);
  };

  var handleClearFilter = function handleClearFilter() {
    column.setColumnFilterValue('');
    setAnchorEl(null);
  };

  var handleFilterByColumn = function handleFilterByColumn() {
    setShowFilters(true);
    setTimeout(function () {
      var _document$getElementB, _header$muiTableHeadC, _header$muiTableHeadC2;

      return (_document$getElementB = document.getElementById( // @ts-ignore
      (_header$muiTableHeadC = (_header$muiTableHeadC2 = header.muiTableHeadCellFilterTextFieldProps) == null ? void 0 : _header$muiTableHeadC2.id) != null ? _header$muiTableHeadC : "mrt-" + idPrefix + "-" + header.id + "-filter-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
    setAnchorEl(null);
  };

  var handleShowAllColumns = function handleShowAllColumns() {
    toggleAllColumnsVisible(true);
    setAnchorEl(null);
  };

  var handleOpenFilterModeMenu = function handleOpenFilterModeMenu(event) {
    event.stopPropagation();
    setFilterMenuAnchorEl(event.currentTarget);
  };

  var handleOpenShowHideColumnsMenu = function handleOpenShowHideColumnsMenu(event) {
    event.stopPropagation();
    setShowHideColumnsMenuAnchorEl(event.currentTarget);
  };

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableSorting && column.getCanSort() && [React.createElement(MenuItem, {
    disabled: !column.getIsSorted(),
    key: 0,
    onClick: handleClearSort,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ClearAllIcon, null)), localization.clearSort)), React.createElement(MenuItem, {
    disabled: column.getIsSorted() === 'asc',
    key: 1,
    onClick: handleSortAsc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, null)), (_localization$sortByC = localization.sortByColumnAsc) == null ? void 0 : _localization$sortByC.replace('{column}', String(column.header)))), React.createElement(MenuItem, {
    divider: enableColumnFilters || enableGrouping || enableHiding,
    key: 2,
    disabled: column.getIsSorted() === 'desc',
    onClick: handleSortDesc,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(SortIcon, {
    style: {
      transform: 'rotate(180deg) scaleX(-1)'
    }
  })), (_localization$sortByC2 = localization.sortByColumnDesc) == null ? void 0 : _localization$sortByC2.replace('{column}', String(column.header))))], enableColumnFilters && column.getCanColumnFilter() && [React.createElement(MenuItem, {
    disabled: !column.getColumnFilterValue(),
    key: 0,
    onClick: handleClearFilter,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListOffIcon, null)), localization.clearFilter)), React.createElement(MenuItem, {
    divider: enableGrouping || enableHiding,
    key: 1,
    onClick: handleFilterByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(FilterListIcon, null)), (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(column.header))), !column.filterSelectOptions && React.createElement(IconButton, {
    onClick: handleOpenFilterModeMenu,
    onMouseEnter: handleOpenFilterModeMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_FilterTypeMenu, {
    anchorEl: filterMenuAnchorEl,
    header: header,
    key: 2,
    onSelect: handleFilterByColumn,
    setAnchorEl: setFilterMenuAnchorEl,
    tableInstance: tableInstance
  })], enableGrouping && column.getCanGroup() && [React.createElement(MenuItem, {
    divider: enableColumnPinning,
    key: 0,
    onClick: handleGroupByColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(DynamicFeedIcon, null)), (_localization = localization[column.getIsGrouped() ? 'ungroupByColumn' : 'groupByColumn']) == null ? void 0 : _localization.replace('{column}', String(column.header))))], enableColumnPinning && column.getCanPin() && [React.createElement(MenuItem, {
    disabled: column.getIsPinned() === 'left',
    key: 0,
    onClick: function onClick() {
      return handlePinColumn('left');
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(90deg)'
    }
  })), localization.pinToLeft)), React.createElement(MenuItem, {
    disabled: column.getIsPinned() === 'right',
    key: 0,
    onClick: function onClick() {
      return handlePinColumn('right');
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, {
    style: {
      transform: 'rotate(-90deg)'
    }
  })), localization.pinToRight)), React.createElement(MenuItem, {
    disabled: !column.getIsPinned(),
    divider: enableHiding,
    key: 0,
    onClick: function onClick() {
      return handlePinColumn(false);
    },
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(PushPinIcon, null)), localization.unpin))], enableHiding && [React.createElement(MenuItem, {
    disabled: column.enableHiding === false,
    key: 0,
    onClick: handleHideColumn,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(VisibilityOffIcon, null)), (_localization$hideCol = localization.hideColumn) == null ? void 0 : _localization$hideCol.replace('{column}', String(column.header)))), React.createElement(MenuItem, {
    disabled: !Object.values(columnVisibility).filter(function (visible) {
      return !visible;
    }).length,
    key: 1,
    onClick: handleShowAllColumns,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(ViewColumnIcon, null)), (_localization$showAll = localization.showAllColumns) == null ? void 0 : _localization$showAll.replace('{column}', String(column.header))), React.createElement(IconButton, {
    onClick: handleOpenShowHideColumnsMenu,
    onMouseEnter: handleOpenShowHideColumnsMenu,
    size: "small",
    sx: {
      p: 0
    }
  }, React.createElement(ArrowRightIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: showHideColumnsMenuAnchorEl,
    isSubMenu: true,
    key: 2,
    setAnchorEl: setShowHideColumnsMenuAnchorEl,
    tableInstance: tableInstance
  })]);
};

var MRT_RowActionMenu = function MRT_RowActionMenu(_ref) {
  var anchorEl = _ref.anchorEl,
      handleEdit = _ref.handleEdit,
      row = _ref.row,
      setAnchorEl = _ref.setAnchorEl,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      EditIcon = _tableInstance$option.icons.EditIcon,
      enableRowEditing = _tableInstance$option.enableRowEditing,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React.createElement(Menu, {
    anchorEl: anchorEl,
    open: !!anchorEl,
    onClose: function onClose() {
      return setAnchorEl(null);
    },
    MenuListProps: {
      dense: isDensePadding
    }
  }, enableRowEditing && React.createElement(MenuItem, {
    onClick: handleEdit,
    sx: commonMenuItemStyles$1
  }, React.createElement(Box, {
    sx: commonListItemStyles
  }, React.createElement(ListItemIcon, null, React.createElement(EditIcon, null)), localization.edit)), renderRowActionMenuItems == null ? void 0 : renderRowActionMenuItems({
    row: row,
    tableInstance: tableInstance,
    closeMenu: function closeMenu() {
      return setAnchorEl(null);
    }
  }));
};

var MRT_EditActionButtons = function MRT_EditActionButtons(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      CancelIcon = _tableInstance$option2.CancelIcon,
      SaveIcon = _tableInstance$option2.SaveIcon,
      localization = _tableInstance$option.localization,
      onRowEditSubmit = _tableInstance$option.onRowEditSubmit,
      setCurrentEditingRow = _tableInstance$option.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var handleCancel = function handleCancel() {
    var _row$original;

    row.values = (_row$original = row.original) != null ? _row$original : {};
    setCurrentEditingRow(null);
  };

  var handleSave = function handleSave() {
    onRowEditSubmit == null ? void 0 : onRowEditSubmit({
      row: currentEditingRow != null ? currentEditingRow : row,
      tableInstance: tableInstance
    });
    setCurrentEditingRow(null);
  };

  return React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.75rem'
    }
  }, React.createElement(Tooltip, {
    arrow: true,
    title: localization.cancel
  }, React.createElement(IconButton, {
    "aria-label": localization.cancel,
    onClick: handleCancel
  }, React.createElement(CancelIcon, null))), React.createElement(Tooltip, {
    arrow: true,
    title: localization.save
  }, React.createElement(IconButton, {
    "aria-label": localization.save,
    color: "info",
    onClick: handleSave
  }, React.createElement(SaveIcon, null))));
};

var commonIconButtonStyles = {
  height: '2rem',
  ml: '10px',
  opacity: 0.5,
  transition: 'opacity 0.2s',
  width: '2rem',
  '&:hover': {
    opacity: 1
  }
};
var MRT_ToggleRowActionMenuButton = function MRT_ToggleRowActionMenuButton(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableRowEditing = _tableInstance$option.enableRowEditing,
      _tableInstance$option2 = _tableInstance$option.icons,
      EditIcon = _tableInstance$option2.EditIcon,
      MoreHorizIcon = _tableInstance$option2.MoreHorizIcon,
      localization = _tableInstance$option.localization,
      renderRowActionMenuItems = _tableInstance$option.renderRowActionMenuItems,
      renderRowActions = _tableInstance$option.renderRowActions,
      setCurrentEditingRow = _tableInstance$option.setCurrentEditingRow;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleOpenRowActionMenu = function handleOpenRowActionMenu(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var handleEdit = function handleEdit() {
    setCurrentEditingRow(_extends({}, row));
    setAnchorEl(null);
  };

  return React.createElement(React.Fragment, null, renderRowActions ? React.createElement(React.Fragment, null, renderRowActions({
    row: row,
    tableInstance: tableInstance
  })) : row.id === (currentEditingRow == null ? void 0 : currentEditingRow.id) ? React.createElement(MRT_EditActionButtons, {
    row: row,
    tableInstance: tableInstance
  }) : !renderRowActionMenuItems && enableRowEditing ? React.createElement(Tooltip, {
    placement: "right",
    arrow: true,
    title: localization.edit
  }, React.createElement(IconButton, {
    sx: commonIconButtonStyles,
    onClick: handleEdit
  }, React.createElement(EditIcon, null))) : renderRowActionMenuItems ? React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: localization.rowActions
  }, React.createElement(IconButton, {
    "aria-label": localization.rowActions,
    onClick: handleOpenRowActionMenu,
    size: "small",
    sx: commonIconButtonStyles
  }, React.createElement(MoreHorizIcon, null))), React.createElement(MRT_RowActionMenu, {
    anchorEl: anchorEl,
    handleEdit: handleEdit,
    row: row,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  })) : null);
};

var MRT_SelectCheckbox = function MRT_SelectCheckbox(_ref) {
  var row = _ref.row,
      selectAll = _ref.selectAll,
      tableInstance = _ref.tableInstance;
  var getRowModel = tableInstance.getRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      getToggleAllRowsSelectedProps = tableInstance.getToggleAllRowsSelectedProps,
      _tableInstance$option = tableInstance.options,
      isLoading = _tableInstance$option.isLoading,
      localization = _tableInstance$option.localization,
      muiSelectCheckboxProps = _tableInstance$option.muiSelectCheckboxProps,
      onSelectChange = _tableInstance$option.onSelectChange,
      onSelectAllChange = _tableInstance$option.onSelectAllChange;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var handleSelectChange = function handleSelectChange(event) {
    if (selectAll) {
      var _getToggleAllRowsSele;

      getToggleAllRowsSelectedProps == null ? void 0 : (_getToggleAllRowsSele = getToggleAllRowsSelectedProps()) == null ? void 0 : _getToggleAllRowsSele.onChange == null ? void 0 : _getToggleAllRowsSele.onChange(event);
      onSelectAllChange == null ? void 0 : onSelectAllChange({
        event: event,
        selectedRows: event.target.checked ? getRowModel().flatRows : [],
        tableInstance: tableInstance
      });
    } else if (row) {
      var _row$getToggleSelecte;

      row == null ? void 0 : (_row$getToggleSelecte = row.getToggleSelectedProps()) == null ? void 0 : _row$getToggleSelecte.onChange == null ? void 0 : _row$getToggleSelecte.onChange(event);
      onSelectChange == null ? void 0 : onSelectChange({
        event: event,
        row: row,
        selectedRows: event.target.checked ? [].concat(getSelectedRowModel().flatRows, [row]) : getSelectedRowModel().flatRows.filter(function (selectedRow) {
          return selectedRow.id !== row.id;
        }),
        tableInstance: tableInstance
      });
    }
  };

  var mTableBodyRowSelectCheckboxProps = muiSelectCheckboxProps instanceof Function ? muiSelectCheckboxProps({
    isSelectAll: !!selectAll,
    row: row,
    tableInstance: tableInstance
  }) : muiSelectCheckboxProps;
  var rtSelectCheckboxProps = selectAll ? getToggleAllRowsSelectedProps() : row == null ? void 0 : row.getToggleSelectedProps();

  var checkboxProps = _extends({}, rtSelectCheckboxProps, mTableBodyRowSelectCheckboxProps);

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    title: selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
  }, React.createElement(Checkbox, Object.assign({
    disabled: isLoading,
    inputProps: {
      'aria-label': selectAll ? localization.toggleSelectAll : localization.toggleSelectRow
    },
    size: isDensePadding ? 'small' : 'medium'
  }, checkboxProps, {
    sx: {
      height: isDensePadding ? '1.75rem' : '2.25rem',
      width: isDensePadding ? '1.75rem' : '2.25rem'
    },
    onChange: handleSelectChange,
    title: undefined
  })));
};

var MRT_SearchTextField = function MRT_SearchTextField(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      setGlobalFilter = tableInstance.setGlobalFilter,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      idPrefix = _tableInstance$option.idPrefix,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      onGlobalFilterChange = _tableInstance$option.onGlobalFilterChange;

  var _getState = getState(),
      globalFilter = _getState.globalFilter,
      showSearch = _getState.showSearch;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var _useState2 = useState(globalFilter != null ? globalFilter : ''),
      searchValue = _useState2[0],
      setSearchValue = _useState2[1];

  var handleChange = useCallback(debounce(function (event) {
    var _event$target$value;

    setGlobalFilter((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
    onGlobalFilterChange == null ? void 0 : onGlobalFilterChange({
      event: event,
      tableInstance: tableInstance
    });
  }, 200), []);

  var handleGlobalFilterMenuOpen = function handleGlobalFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setSearchValue('');
    setGlobalFilter(undefined);
  };

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;
  return React.createElement(Collapse, {
    "in": showSearch,
    orientation: "horizontal"
  }, React.createElement(TextField, Object.assign({
    id: "mrt-" + idPrefix + "-search-text-field",
    placeholder: localization.search,
    onChange: function onChange(event) {
      setSearchValue(event.target.value);
      handleChange(event);
    },
    value: searchValue != null ? searchValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(Tooltip, {
        arrow: true,
        title: localization.changeSearchMode
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.changeSearchMode,
        onClick: handleGlobalFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(SearchIcon, {
        fontSize: "small"
      }))))),
      endAdornment: React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(IconButton, {
        "aria-label": localization.clearSearch,
        disabled: (searchValue == null ? void 0 : searchValue.length) === 0,
        onClick: handleClear,
        size: "small",
        title: localization.clearSearch
      }, React.createElement(CloseIcon, {
        fontSize: "small"
      })))
    }
  }, textFieldProps, {
    sx: _extends({
      justifySelf: 'end'
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  })), React.createElement(MRT_FilterTypeMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var _excluded = ["tableInstance"];
var MRT_FullScreenToggleButton = function MRT_FullScreenToggleButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FullscreenExitIcon = _tableInstance$option2.FullscreenExitIcon,
      FullscreenIcon = _tableInstance$option2.FullscreenIcon,
      localization = _tableInstance$option.localization,
      setIsFullScreen = _tableInstance$option.setIsFullScreen;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleFullScreen
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: function onClick() {
      return setIsFullScreen(!isFullScreen);
    },
    size: "small"
  }, rest), isFullScreen ? React.createElement(FullscreenExitIcon, null) : React.createElement(FullscreenIcon, null)));
};

var _excluded$1 = ["tableInstance"];
var MRT_ShowHideColumnsButton = function MRT_ShowHideColumnsButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

  var _tableInstance$option = tableInstance.options,
      ViewColumnIcon = _tableInstance$option.icons.ViewColumnIcon,
      localization = _tableInstance$option.localization;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    setAnchorEl(event.currentTarget);
  };

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideColumns
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideColumns,
    onClick: handleClick,
    size: "small"
  }, rest), React.createElement(ViewColumnIcon, null))), React.createElement(MRT_ShowHideColumnsMenu, {
    anchorEl: anchorEl,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var _excluded$2 = ["tableInstance"];
var MRT_ToggleDensePaddingButton = function MRT_ToggleDensePaddingButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$2);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      DensityMediumIcon = _tableInstance$option2.DensityMediumIcon,
      DensitySmallIcon = _tableInstance$option2.DensitySmallIcon,
      localization = _tableInstance$option.localization,
      setIsDensePadding = _tableInstance$option.setIsDensePadding;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.toggleDensePadding
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.toggleDensePadding,
    onClick: function onClick() {
      return setIsDensePadding(!isDensePadding);
    },
    size: "small"
  }, rest), isDensePadding ? React.createElement(DensitySmallIcon, null) : React.createElement(DensityMediumIcon, null)));
};

var _excluded$3 = ["tableInstance"];
var MRT_ToggleFiltersButton = function MRT_ToggleFiltersButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$3);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      FilterListOffIcon = _tableInstance$option2.FilterListOffIcon,
      localization = _tableInstance$option.localization,
      setShowFilters = _tableInstance$option.setShowFilters;

  var _getState = getState(),
      showFilters = _getState.showFilters;

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideFilters
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.showHideFilters,
    onClick: function onClick() {
      return setShowFilters(!showFilters);
    },
    size: "small"
  }, rest), showFilters ? React.createElement(FilterListOffIcon, null) : React.createElement(FilterListIcon, null)));
};

var _excluded$4 = ["tableInstance"];
var MRT_ToggleSearchButton = function MRT_ToggleSearchButton(_ref) {
  var tableInstance = _ref.tableInstance,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$4);

  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      SearchIcon = _tableInstance$option2.SearchIcon,
      SearchOffIcon = _tableInstance$option2.SearchOffIcon,
      idPrefix = _tableInstance$option.idPrefix,
      localization = _tableInstance$option.localization,
      muiSearchTextFieldProps = _tableInstance$option.muiSearchTextFieldProps,
      setShowSearch = _tableInstance$option.setShowSearch;

  var _getState = getState(),
      showSearch = _getState.showSearch;

  var textFieldProps = muiSearchTextFieldProps instanceof Function ? muiSearchTextFieldProps({
    tableInstance: tableInstance
  }) : muiSearchTextFieldProps;

  var handleToggleSearch = function handleToggleSearch() {
    setShowSearch(!showSearch);
    setTimeout(function () {
      var _document$getElementB, _textFieldProps$id;

      return (_document$getElementB = document.getElementById((_textFieldProps$id = textFieldProps == null ? void 0 : textFieldProps.id) != null ? _textFieldProps$id : "mrt-" + idPrefix + "-search-text-field")) == null ? void 0 : _document$getElementB.focus();
    }, 200);
  };

  return React.createElement(Tooltip, {
    arrow: true,
    title: localization.showHideSearch
  }, React.createElement(IconButton, Object.assign({
    size: "small",
    onClick: handleToggleSearch
  }, rest), showSearch ? React.createElement(SearchOffIcon, null) : React.createElement(SearchIcon, null)));
};

var MRT_ToolbarInternalButtons = function MRT_ToolbarInternalButtons(_ref) {
  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableHiding = _tableInstance$option.enableHiding,
      enableDensePaddingToggle = _tableInstance$option.enableDensePaddingToggle,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enableFullScreenToggle = _tableInstance$option.enableFullScreenToggle,
      renderToolbarInternalActions = _tableInstance$option.renderToolbarInternalActions;

  if (renderToolbarInternalActions) {
    return React.createElement(React.Fragment, null, renderToolbarInternalActions({
      MRT_FullScreenToggleButton: MRT_FullScreenToggleButton,
      MRT_ShowHideColumnsButton: MRT_ShowHideColumnsButton,
      MRT_ToggleDensePaddingButton: MRT_ToggleDensePaddingButton,
      MRT_ToggleFiltersButton: MRT_ToggleFiltersButton,
      MRT_ToggleSearchButton: MRT_ToggleSearchButton,
      tableInstance: tableInstance
    }));
  }

  return React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.5rem',
      alignItems: 'center',
      p: '0 0.5rem'
    }
  }, enableGlobalFilter && React.createElement(MRT_ToggleSearchButton, {
    tableInstance: tableInstance
  }), enableColumnFilters && React.createElement(MRT_ToggleFiltersButton, {
    tableInstance: tableInstance
  }), enableHiding && React.createElement(MRT_ShowHideColumnsButton, {
    tableInstance: tableInstance
  }), enableDensePaddingToggle && React.createElement(MRT_ToggleDensePaddingButton, {
    tableInstance: tableInstance
  }), enableFullScreenToggle && React.createElement(MRT_FullScreenToggleButton, {
    tableInstance: tableInstance
  }));
};

var MRT_TablePagination = function MRT_TablePagination(_ref) {
  var tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getState = tableInstance.getState,
      setPageIndex = tableInstance.setPageIndex,
      setPageSize = tableInstance.setPageSize,
      muiTablePaginationProps = tableInstance.options.muiTablePaginationProps;

  var _getState = getState(),
      _getState$pagination = _getState.pagination,
      _getState$pagination$ = _getState$pagination.pageSize,
      pageSize = _getState$pagination$ === void 0 ? 10 : _getState$pagination$,
      _getState$pagination$2 = _getState$pagination.pageIndex,
      pageIndex = _getState$pagination$2 === void 0 ? 0 : _getState$pagination$2;

  var tablePaginationProps = muiTablePaginationProps instanceof Function ? muiTablePaginationProps({
    tableInstance: tableInstance
  }) : muiTablePaginationProps;

  var handleChangeRowsPerPage = function handleChangeRowsPerPage(event) {
    setPageSize(+event.target.value);
  };

  var showFirstLastPageButtons = getPrePaginationRowModel().rows.length / pageSize > 2;
  return React.createElement(TablePagination, Object.assign({
    SelectProps: {
      sx: {
        m: '0 1rem 0 1ch'
      },
      MenuProps: {
        MenuListProps: {
          disablePadding: true
        }
      }
    },
    component: "div",
    count: getPrePaginationRowModel().rows.length,
    onPageChange: function onPageChange(_, newPage) {
      return setPageIndex(newPage);
    },
    onRowsPerPageChange: handleChangeRowsPerPage,
    page: pageIndex,
    rowsPerPage: pageSize,
    rowsPerPageOptions: [5, 10, 15, 20, 25, 30, 50, 100],
    showFirstButton: showFirstLastPageButtons,
    showLastButton: showFirstLastPageButtons
  }, tablePaginationProps, {
    sx: _extends({
      m: '0 0.5rem',
      position: 'relative',
      zIndex: 2
    }, tablePaginationProps == null ? void 0 : tablePaginationProps.sx)
  }));
};

var MRT_ToolbarAlertBanner = function MRT_ToolbarAlertBanner(_ref) {
  var _localization$selecte, _localization$selecte2;

  var tableInstance = _ref.tableInstance;
  var getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getSelectedRowModel = tableInstance.getSelectedRowModel,
      getState = tableInstance.getState,
      toggleColumnGrouping = tableInstance.toggleColumnGrouping,
      _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableToolbarAlertBannerProps = _tableInstance$option.muiTableToolbarAlertBannerProps,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      grouping = _getState.grouping;

  var isMobile = useMediaQuery('(max-width:720px)');
  var alertProps = muiTableToolbarAlertBannerProps instanceof Function ? muiTableToolbarAlertBannerProps({
    tableInstance: tableInstance
  }) : muiTableToolbarAlertBannerProps;
  var selectMessage = getSelectedRowModel().rows.length > 0 ? (_localization$selecte = localization.selectedCountOfRowCountRowsSelected) == null ? void 0 : (_localization$selecte2 = _localization$selecte.replace('{selectedCount}', getSelectedRowModel().rows.length.toString())) == null ? void 0 : _localization$selecte2.replace('{rowCount}', getPrePaginationRowModel().rows.length.toString()) : null;
  var groupedByMessage = grouping.length > 0 ? React.createElement("span", null, localization.groupedBy, ' ', grouping.map(function (columnId, index) {
    var _tableInstance$getAll;

    return React.createElement(Fragment, {
      key: index + "-" + columnId
    }, index > 0 ? localization.thenBy : '', React.createElement(Chip, {
      color: "secondary",
      label: (_tableInstance$getAll = tableInstance.getAllColumns().find(function (column) {
        return column.id === columnId;
      })) == null ? void 0 : _tableInstance$getAll.header,
      onDelete: function onDelete() {
        return toggleColumnGrouping(columnId);
      }
    }));
  })) : null;
  var displayAbsolute = !(isMobile || positionToolbarAlertBanner === 'bottom' && positionToolbarActions === 'bottom' || positionToolbarAlertBanner === 'top' && !!renderToolbarCustomActions);
  return React.createElement(Collapse, {
    "in": !!selectMessage || !!groupedByMessage,
    timeout: displayAbsolute ? 0 : 200
  }, React.createElement(Alert, Object.assign({
    color: "info",
    icon: false,
    sx: _extends({
      borderRadius: 0,
      fontSize: '1rem',
      left: 0,
      p: 0,
      position: displayAbsolute ? 'absolute' : 'relative',
      right: 0,
      minHeight: '3.5rem',
      top: 0,
      width: '100%',
      zIndex: 2
    }, alertProps == null ? void 0 : alertProps.sx)
  }, alertProps), React.createElement(Box, {
    sx: {
      p: '0.5rem 1rem'
    }
  }, selectMessage, React.createElement("br", null), groupedByMessage)));
};

var MRT_LinearProgressBar = function MRT_LinearProgressBar(_ref) {
  var tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      muiLinearProgressProps = _tableInstance$option.muiLinearProgressProps,
      isReloading = _tableInstance$option.isReloading,
      isLoading = _tableInstance$option.isLoading;
  var linearProgressProps = muiLinearProgressProps instanceof Function ? muiLinearProgressProps({
    tableInstance: tableInstance
  }) : muiLinearProgressProps;
  return React.createElement(Collapse, {
    "in": isReloading || isLoading,
    unmountOnExit: true
  }, React.createElement(LinearProgress, Object.assign({
    "aria-label": "Loading",
    "aria-busy": "true"
  }, linearProgressProps)));
};

var commonToolbarStyles = function commonToolbarStyles(_ref) {
  var theme = _ref.theme;
  return {
    backgroundColor: theme.palette.background["default"],
    backgroundImage: "linear-gradient(" + alpha(theme.palette.common.white, 0.05) + "," + alpha(theme.palette.common.white, 0.05) + ")",
    display: 'grid',
    p: '0 !important',
    width: '100%',
    zIndex: 1
  };
};
var MRT_ToolbarTop = function MRT_ToolbarTop(_ref2) {
  var _renderToolbarCustomA;

  var tableInstance = _ref2.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableGlobalFilter = _tableInstance$option.enableGlobalFilter,
      enablePagination = _tableInstance$option.enablePagination,
      hideToolbarInternalActions = _tableInstance$option.hideToolbarInternalActions,
      idPrefix = _tableInstance$option.idPrefix,
      muiTableToolbarTopProps = _tableInstance$option.muiTableToolbarTopProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner,
      renderToolbarCustomActions = _tableInstance$option.renderToolbarCustomActions;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var toolbarProps = muiTableToolbarTopProps instanceof Function ? muiTableToolbarTopProps({
    tableInstance: tableInstance
  }) : muiTableToolbarTopProps;
  return React.createElement(Toolbar, Object.assign({
    id: "mrt-" + idPrefix + "-toolbar-top",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({
        position: isFullScreen ? 'sticky' : undefined,
        top: isFullScreen ? '0' : undefined
      }, commonToolbarStyles({
        theme: theme
      }), toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), positionToolbarAlertBanner === 'top' && React.createElement(MRT_ToolbarAlertBanner, {
    tableInstance: tableInstance
  }), React.createElement(Box, {
    sx: {
      p: '0.5rem',
      display: 'flex',
      justifyContent: 'space-between'
    }
  }, (_renderToolbarCustomA = renderToolbarCustomActions == null ? void 0 : renderToolbarCustomActions({
    tableInstance: tableInstance
  })) != null ? _renderToolbarCustomA : React.createElement("span", null), React.createElement(Box, {
    sx: {
      display: 'flex',
      gap: '0.5rem',
      position: 'relative',
      zIndex: 3
    }
  }, enableGlobalFilter && React.createElement(MRT_SearchTextField, {
    tableInstance: tableInstance
  }), !hideToolbarInternalActions && positionToolbarActions === 'top' && React.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  }))), React.createElement("div", null, enablePagination && ['top', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })), React.createElement(MRT_LinearProgressBar, {
    tableInstance: tableInstance
  }));
};

var MRT_ToolbarBottom = function MRT_ToolbarBottom(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      hideToolbarInternalActions = _tableInstance$option.hideToolbarInternalActions,
      idPrefix = _tableInstance$option.idPrefix,
      enablePagination = _tableInstance$option.enablePagination,
      muiTableToolbarBottomProps = _tableInstance$option.muiTableToolbarBottomProps,
      positionPagination = _tableInstance$option.positionPagination,
      positionToolbarActions = _tableInstance$option.positionToolbarActions,
      positionToolbarAlertBanner = _tableInstance$option.positionToolbarAlertBanner;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  var toolbarProps = muiTableToolbarBottomProps instanceof Function ? muiTableToolbarBottomProps({
    tableInstance: tableInstance
  }) : muiTableToolbarBottomProps;
  return React.createElement(Toolbar, Object.assign({
    id: "mrt-" + idPrefix + "-toolbar-bottom",
    variant: "dense"
  }, toolbarProps, {
    sx: function sx(theme) {
      return _extends({}, commonToolbarStyles({
        theme: theme
      }), {
        bottom: isFullScreen ? '0' : undefined,
        position: isFullScreen ? 'fixed' : undefined,
        boxShadow: "-3px 0 6px " + alpha(theme.palette.common.black, 0.1)
      }, toolbarProps == null ? void 0 : toolbarProps.sx);
    }
  }), React.createElement(MRT_LinearProgressBar, {
    tableInstance: tableInstance
  }), React.createElement(Box, {
    sx: {
      display: 'flex',
      justifyContent: 'space-between',
      width: '100%'
    }
  }, !hideToolbarInternalActions && positionToolbarActions === 'bottom' ? React.createElement(MRT_ToolbarInternalButtons, {
    tableInstance: tableInstance
  }) : React.createElement("span", null), positionToolbarAlertBanner === 'bottom' && React.createElement(MRT_ToolbarAlertBanner, {
    tableInstance: tableInstance
  }), enablePagination && ['bottom', 'both'].includes(positionPagination != null ? positionPagination : '') && React.createElement(MRT_TablePagination, {
    tableInstance: tableInstance
  })));
};

var MRT_FilterTextField = function MRT_FilterTextField(_ref) {
  var _column$getColumnFilt, _localization$filterB, _localization$filterM, _localization$, _localization$clearFi, _column$filterSelectO;

  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterListIcon = _tableInstance$option2.FilterListIcon,
      CloseIcon = _tableInstance$option2.CloseIcon,
      idPrefix = _tableInstance$option.idPrefix,
      localization = _tableInstance$option.localization,
      muiTableHeadCellFilterTextFieldProps = _tableInstance$option.muiTableHeadCellFilterTextFieldProps,
      setCurrentFilterTypes = _tableInstance$option.setCurrentFilterTypes;
  var column = header.column;

  var _getState = getState(),
      currentFilterTypes = _getState.currentFilterTypes;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var mTableHeadCellFilterTextFieldProps = muiTableHeadCellFilterTextFieldProps instanceof Function ? muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellFilterTextFieldProps;
  var mcTableHeadCellFilterTextFieldProps = column.muiTableHeadCellFilterTextFieldProps instanceof Function ? column.muiTableHeadCellFilterTextFieldProps({
    column: column,
    tableInstance: tableInstance
  }) : column.muiTableHeadCellFilterTextFieldProps;

  var textFieldProps = _extends({}, mTableHeadCellFilterTextFieldProps, mcTableHeadCellFilterTextFieldProps);

  var _useState2 = useState((_column$getColumnFilt = column.getColumnFilterValue()) != null ? _column$getColumnFilt : ''),
      filterValue = _useState2[0],
      setFilterValue = _useState2[1];

  var handleChange = useCallback(debounce(function (event) {
    var _event$target$value;

    return column.setColumnFilterValue((_event$target$value = event.target.value) != null ? _event$target$value : undefined);
  }, 150), []);

  var handleFilterMenuOpen = function handleFilterMenuOpen(event) {
    setAnchorEl(event.currentTarget);
  };

  var handleClear = function handleClear() {
    setFilterValue('');
    column.setColumnFilterValue(undefined);
  };

  var handleClearFilterChip = function handleClearFilterChip() {
    setFilterValue('');
    column.setColumnFilterValue(undefined);
    setCurrentFilterTypes(function (prev) {
      var _extends2;

      return _extends({}, prev, (_extends2 = {}, _extends2[header.id] = MRT_FILTER_TYPE.BEST_MATCH, _extends2));
    });
  };

  if (column.Filter) {
    return React.createElement(React.Fragment, null, column.Filter == null ? void 0 : column.Filter({
      header: header,
      tableInstance: tableInstance
    }));
  }

  var filterId = "mrt-" + idPrefix + "-" + header.id + "-filter-text-field";
  var filterType = currentFilterTypes == null ? void 0 : currentFilterTypes[header.id];
  var isSelectFilter = !!column.filterSelectOptions;
  var filterChipLabel = !(filterType instanceof Function) && [MRT_FILTER_TYPE.EMPTY, MRT_FILTER_TYPE.NOT_EMPTY].includes(filterType) ? //@ts-ignore
  localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))] : '';
  var filterPlaceholder = (_localization$filterB = localization.filterByColumn) == null ? void 0 : _localization$filterB.replace('{column}', String(column.header));
  return React.createElement(React.Fragment, null, React.createElement(TextField, Object.assign({
    fullWidth: true,
    id: filterId,
    inputProps: {
      disabled: !!filterChipLabel,
      sx: {
        textOverflow: 'ellipsis',
        width: filterChipLabel ? 0 : undefined
      },
      title: filterPlaceholder
    },
    helperText: React.createElement("label", {
      htmlFor: filterId
    }, filterType instanceof Function ? (_localization$filterM = localization.filterMode.replace('{filterType}', // @ts-ignore
    (_localization$ = localization["filter" + (filterType.name.charAt(0).toUpperCase() + filterType.name.slice(1))]) != null ? _localization$ : '')) != null ? _localization$filterM : '' : localization.filterMode.replace('{filterType}', // @ts-ignore
    localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))])),
    FormHelperTextProps: {
      sx: {
        fontSize: '0.6rem',
        lineHeight: '0.8rem'
      }
    },
    label: isSelectFilter && !filterValue ? filterPlaceholder : undefined,
    margin: "none",
    placeholder: filterPlaceholder,
    onChange: function onChange(event) {
      setFilterValue(event.target.value);
      handleChange(event);
    },
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    select: isSelectFilter,
    value: filterValue != null ? filterValue : '',
    variant: "standard",
    InputProps: {
      startAdornment: !isSelectFilter && React.createElement(InputAdornment, {
        position: "start"
      }, React.createElement(Tooltip, {
        arrow: true,
        title: localization.changeFilterMode
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.changeFilterMode,
        onClick: handleFilterMenuOpen,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(FilterListIcon, null)))), filterChipLabel && React.createElement(Chip, {
        onDelete: handleClearFilterChip,
        label: filterChipLabel
      })),
      endAdornment: !filterChipLabel && React.createElement(InputAdornment, {
        position: "end"
      }, React.createElement(Tooltip, {
        arrow: true,
        disableHoverListener: isSelectFilter,
        placement: "right",
        title: (_localization$clearFi = localization.clearFilter) != null ? _localization$clearFi : ''
      }, React.createElement("span", null, React.createElement(IconButton, {
        "aria-label": localization.clearFilter,
        disabled: !(filterValue != null && filterValue.length),
        onClick: handleClear,
        size: "small",
        sx: {
          height: '1.75rem',
          width: '1.75rem'
        }
      }, React.createElement(CloseIcon, {
        fontSize: "small"
      })))))
    }
  }, textFieldProps, {
    sx: _extends({
      m: '-0.25rem',
      p: 0,
      minWidth: !filterChipLabel ? '5rem' : 'auto',
      width: 'calc(100% + 0.5rem)',
      mt: isSelectFilter && !filterValue ? '-1rem' : undefined,
      '&	.MuiSelect-icon': {
        mr: '1.5rem'
      }
    }, textFieldProps == null ? void 0 : textFieldProps.sx)
  }), isSelectFilter && React.createElement(MenuItem, {
    divider: true,
    disabled: !filterValue,
    value: ""
  }, localization.clearFilter), column == null ? void 0 : (_column$filterSelectO = column.filterSelectOptions) == null ? void 0 : _column$filterSelectO.map(function (option) {
    var value;
    var text;

    if (typeof option === 'string') {
      value = option;
      text = option;
    } else if (typeof option === 'object') {
      value = option.value;
      text = option.text;
    }

    return React.createElement(MenuItem, {
      key: value,
      value: value
    }, text);
  })), React.createElement(MRT_FilterTypeMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_ToggleColumnActionMenuButton = function MRT_ToggleColumnActionMenuButton(_ref) {
  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      MoreVertIcon = _tableInstance$option.icons.MoreVertIcon,
      localization = _tableInstance$option.localization,
      muiTableHeadCellColumnActionsButtonProps = _tableInstance$option.muiTableHeadCellColumnActionsButtonProps;
  var column = header.column;

  var _useState = useState(null),
      anchorEl = _useState[0],
      setAnchorEl = _useState[1];

  var handleClick = function handleClick(event) {
    event.stopPropagation();
    event.preventDefault();
    setAnchorEl(event.currentTarget);
  };

  var mTableHeadCellColumnActionsButtonProps = muiTableHeadCellColumnActionsButtonProps instanceof Function ? muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellColumnActionsButtonProps;
  var mcTableHeadCellColumnActionsButtonProps = column.muiTableHeadCellColumnActionsButtonProps instanceof Function ? column.muiTableHeadCellColumnActionsButtonProps({
    column: column,
    tableInstance: tableInstance
  }) : column.muiTableHeadCellColumnActionsButtonProps;

  var iconButtonProps = _extends({}, mTableHeadCellColumnActionsButtonProps, mcTableHeadCellColumnActionsButtonProps);

  return React.createElement(React.Fragment, null, React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: localization.columnActions
  }, React.createElement(IconButton, Object.assign({
    "aria-label": localization.columnActions,
    onClick: handleClick,
    size: "small"
  }, iconButtonProps, {
    sx: _extends({
      height: '2rem',
      mr: '2px',
      mt: '-0.2rem',
      opacity: 0.5,
      transition: 'opacity 0.2s',
      width: '2rem',
      '&:hover': {
        opacity: 1
      }
    }, iconButtonProps.sx)
  }), React.createElement(MoreVertIcon, null))), React.createElement(MRT_ColumnActionMenu, {
    anchorEl: anchorEl,
    header: header,
    setAnchorEl: setAnchorEl,
    tableInstance: tableInstance
  }));
};

var MRT_TableHeadCell = function MRT_TableHeadCell(_ref) {
  var _getState2, _getState2$currentFil, _column$Header;

  var header = _ref.header,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnActions = _tableInstance$option.enableColumnActions,
      enableColumnFilters = _tableInstance$option.enableColumnFilters,
      enableColumnResizing = _tableInstance$option.enableColumnResizing,
      _tableInstance$option2 = _tableInstance$option.icons,
      FilterAltIcon = _tableInstance$option2.FilterAltIcon,
      FilterAltOff = _tableInstance$option2.FilterAltOff,
      localization = _tableInstance$option.localization,
      muiTableHeadCellProps = _tableInstance$option.muiTableHeadCellProps,
      setShowFilters = _tableInstance$option.setShowFilters;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding,
      showFilters = _getState.showFilters;

  var column = header.column;
  var mTableHeadCellProps = muiTableHeadCellProps instanceof Function ? muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableHeadCellProps;
  var mcTableHeadCellProps = column.muiTableHeadCellProps instanceof Function ? column.muiTableHeadCellProps({
    column: column,
    tableInstance: tableInstance
  }) : column.muiTableHeadCellProps;

  var tableCellProps = _extends({}, header.getHeaderProps(), mTableHeadCellProps, mcTableHeadCellProps);

  var sortTooltip = !!column.getIsSorted() ? column.getIsSorted() === 'desc' ? localization.clearSort : localization.sortByColumnDesc.replace('{column}', column.header) : localization.sortByColumnAsc.replace('{column}', column.header);
  var filterType = (_getState2 = getState()) == null ? void 0 : (_getState2$currentFil = _getState2.currentFilterTypes) == null ? void 0 : _getState2$currentFil[header.id];
  var filterTooltip = !!column.getColumnFilterValue() ? localization.filteringByColumn.replace('{column}', String(column.header)).replace('{filterType}', filterType instanceof Function ? '' : // @ts-ignore
  localization["filter" + (filterType.charAt(0).toUpperCase() + filterType.slice(1))]).replace('{filterValue}', column.getColumnFilterValue()).replace('" "', '') : localization.showHideFilters;
  var headerElement = (_column$Header = column == null ? void 0 : column.Header == null ? void 0 : column.Header({
    header: header,
    tableInstance: tableInstance
  })) != null ? _column$Header : column.header;
  return React.createElement(TableCell, Object.assign({
    align: column.columnDefType === 'group' ? 'center' : 'left'
  }, tableCellProps, {
    //@ts-ignore
    sx: function sx(theme) {
      return _extends({
        backgroundColor: theme.palette.background["default"],
        backgroundImage: "linear-gradient(" + alpha(theme.palette.common.white, 0.05) + "," + alpha(theme.palette.common.white, 0.05) + ")",
        boxShadow: "3px 0 6px " + alpha(theme.palette.common.black, 0.1),
        fontWeight: 'bold',
        height: '100%',
        minWidth: "max(" + header.getWidth() + ", 100px)",
        p: isDensePadding ? column.columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : column.columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
        pt: column.columnDefType === 'display' ? 0 : isDensePadding ? '0.75rem' : '1.25rem',
        pb: column.columnDefType === 'display' ? 0 : undefined,
        transition: "all " + (enableColumnResizing ? 0 : '0.2s') + " ease-in-out",
        verticalAlign: 'text-top',
        width: header.getWidth()
      }, tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), header.isPlaceholder ? null : column.columnDefType === 'display' ? headerElement : React.createElement(Box, {
    sx: {
      alignItems: 'flex-start',
      display: 'flex',
      justifyContent: column.columnDefType === 'group' ? 'center' : 'space-between',
      width: '100%'
    }
  }, React.createElement(Box, Object.assign({}, column.getToggleSortingProps(), {
    sx: {
      alignItems: 'center',
      cursor: column.getCanSort() && column.columnDefType !== 'group' ? 'pointer' : undefined,
      display: 'flex',
      flexWrap: 'nowrap',
      whiteSpace: column.header.length < 15 ? 'nowrap' : 'normal'
    },
    title: undefined
  }), headerElement, column.columnDefType !== 'group' && column.getCanSort() && React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: sortTooltip
  }, React.createElement(TableSortLabel, {
    "aria-label": sortTooltip,
    active: !!column.getIsSorted(),
    direction: column.getIsSorted() ? column.getIsSorted() : undefined
  })), column.columnDefType !== 'group' && enableColumnFilters && !!column.getCanColumnFilter() && React.createElement(Tooltip, {
    arrow: true,
    placement: "top",
    title: filterTooltip
  }, React.createElement(IconButton, {
    disableRipple: true,
    onClick: function onClick(event) {
      event.stopPropagation();
      setShowFilters(!showFilters);
    },
    size: "small",
    sx: {
      m: 0,
      opacity: !!column.getColumnFilterValue() ? 0.8 : 0,
      p: '2px',
      transition: 'all 0.2s ease-in-out',
      '&:hover': {
        backgroundColor: 'transparent',
        opacity: 0.8
      }
    }
  }, showFilters && !column.getColumnFilterValue() ? React.createElement(FilterAltOff, {
    fontSize: "small"
  }) : React.createElement(FilterAltIcon, {
    fontSize: "small"
  })))), React.createElement(Box, {
    sx: {
      alignItems: 'center',
      display: 'flex',
      flexWrap: 'nowrap'
    }
  }, (enableColumnActions || column.enableColumnActions) && column.enableColumnActions !== false && column.columnDefType !== 'group' && React.createElement(MRT_ToggleColumnActionMenuButton, {
    header: header,
    tableInstance: tableInstance
  }), enableColumnResizing && column.columnDefType !== 'group' && React.createElement(Divider, Object.assign({
    flexItem: true,
    orientation: "vertical",
    onDoubleClick: function onDoubleClick() {
      return header.resetSize();
    },
    sx: function sx(theme) {
      return {
        borderRightWidth: '2px',
        borderRadius: '2px',
        maxHeight: '2rem',
        cursor: 'col-resize',
        userSelect: 'none',
        touchAction: 'none',
        '&:active': {
          backgroundColor: theme.palette.secondary.dark,
          opacity: 1
        }
      };
    }
  }, header.getResizerProps(function (props) {
    return _extends({}, props, {
      style: {
        transform: column.getIsResizing() ? "translateX(" + getState().columnSizingInfo.deltaOffset + "px)" : ''
      }
    });
  }))))), column.columnDefType === 'data' && enableColumnFilters && column.getCanColumnFilter() && React.createElement(Collapse, {
    "in": showFilters
  }, React.createElement(MRT_FilterTextField, {
    header: header,
    tableInstance: tableInstance
  })));
};

var MRT_TableHeadRow = function MRT_TableHeadRow(_ref) {
  var headerGroup = _ref.headerGroup,
      tableInstance = _ref.tableInstance;
  var muiTableHeadRowProps = tableInstance.options.muiTableHeadRowProps;
  var mTableHeadRowProps = muiTableHeadRowProps instanceof Function ? muiTableHeadRowProps({
    headerGroup: headerGroup,
    tableInstance: tableInstance
  }) : muiTableHeadRowProps;

  var tableRowProps = _extends({}, headerGroup == null ? void 0 : headerGroup.getHeaderGroupProps(), mTableHeadRowProps);

  return React.createElement(TableRow, Object.assign({}, tableRowProps), headerGroup.headers.map(function (header, index) {
    return React.createElement(MRT_TableHeadCell, {
      header: header,
      key: header.id || index,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableHead = function MRT_TableHead(_ref) {
  var pinned = _ref.pinned,
      tableInstance = _ref.tableInstance;
  var getCenterHeaderGroups = tableInstance.getCenterHeaderGroups,
      getHeaderGroups = tableInstance.getHeaderGroups,
      getLeftHeaderGroups = tableInstance.getLeftHeaderGroups,
      getRightHeaderGroups = tableInstance.getRightHeaderGroups,
      muiTableHeadProps = tableInstance.options.muiTableHeadProps;
  var tableHeadProps = muiTableHeadProps instanceof Function ? muiTableHeadProps({
    tableInstance: tableInstance
  }) : muiTableHeadProps;
  var getHeaderGroupsMap = {
    center: getCenterHeaderGroups,
    left: getLeftHeaderGroups,
    none: getHeaderGroups,
    right: getRightHeaderGroups
  };
  return React.createElement(TableHead, Object.assign({}, tableHeadProps), getHeaderGroupsMap[pinned]().map(function (headerGroup) {
    return React.createElement(MRT_TableHeadRow, {
      headerGroup: headerGroup,
      key: headerGroup.getHeaderGroupProps().key,
      tableInstance: tableInstance
    });
  }));
};

var MRT_EditCellTextField = function MRT_EditCellTextField(_ref) {
  var cell = _ref.cell,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableRowEditing = _tableInstance$option.enableRowEditing,
      muiTableBodyCellEditTextFieldProps = _tableInstance$option.muiTableBodyCellEditTextFieldProps;
  var column = cell.column,
      row = cell.row;

  var handleChange = function handleChange(event) {
    if (getState().currentEditingRow) {
      row.values[column.id] = event.target.value; // setCurrentEditingRow({
      //   ...getState().currentEditingRow,
      // });
    }

    column.onCellEditChange == null ? void 0 : column.onCellEditChange({
      event: event,
      cell: cell,
      tableInstance: tableInstance
    });
  };

  var mTableBodyCellEditTextFieldProps = muiTableBodyCellEditTextFieldProps instanceof Function ? muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellEditTextFieldProps;
  var mcTableBodyCellEditTextFieldProps = column.muiTableBodyCellEditTextFieldProps instanceof Function ? column.muiTableBodyCellEditTextFieldProps({
    cell: cell,
    tableInstance: tableInstance
  }) : column.muiTableBodyCellEditTextFieldProps;

  var textFieldProps = _extends({}, mTableBodyCellEditTextFieldProps, mcTableBodyCellEditTextFieldProps);

  if (enableRowEditing && column.enableEditing !== false && column.Edit) {
    return React.createElement(React.Fragment, null, column.Edit == null ? void 0 : column.Edit({
      cell: cell,
      tableInstance: tableInstance
    }));
  }

  return React.createElement(TextField, Object.assign({
    margin: "dense",
    onChange: handleChange,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    placeholder: column.header,
    value: cell.value,
    variant: "standard"
  }, textFieldProps));
};

var MRT_CopyButton = function MRT_CopyButton(_ref) {
  var cell = _ref.cell,
      children = _ref.children,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      localization = _tableInstance$option.localization,
      muiTableBodyCellCopyButtonProps = _tableInstance$option.muiTableBodyCellCopyButtonProps;

  var _useState = useState(false),
      copied = _useState[0],
      setCopied = _useState[1];

  var handleCopy = function handleCopy(text) {
    navigator.clipboard.writeText(text);
    setCopied(true);
    setTimeout(function () {
      return setCopied(false);
    }, 4000);
  };

  var mTableBodyCellCopyButtonProps = muiTableBodyCellCopyButtonProps instanceof Function ? muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellCopyButtonProps;
  var mcTableBodyCellCopyButtonProps = cell.column.muiTableBodyCellCopyButtonProps instanceof Function ? cell.column.muiTableBodyCellCopyButtonProps({
    cell: cell,
    tableInstance: tableInstance
  }) : cell.column.muiTableBodyCellCopyButtonProps;

  var buttonProps = _extends({}, mTableBodyCellCopyButtonProps, mcTableBodyCellCopyButtonProps);

  return React.createElement(Tooltip, {
    arrow: true,
    enterDelay: 1000,
    enterNextDelay: 1000,
    placement: "top",
    title: copied ? localization.copiedToClipboard : localization.clickToCopy
  }, React.createElement(Button, Object.assign({
    "aria-label": localization.clickToCopy,
    onClick: function onClick() {
      return handleCopy(cell.value);
    },
    size: "small"
  }, buttonProps, {
    sx: _extends({
      backgroundColor: 'transparent',
      border: 'none',
      color: 'inherit',
      fontFamily: 'inherit',
      fontSize: 'inherit',
      letterSpacing: 'inherit',
      m: '-0.25rem',
      minWidth: 'unset',
      textAlign: 'inherit',
      textTransform: 'inherit'
    }, buttonProps == null ? void 0 : buttonProps.sx),
    variant: "text"
  }), children));
};

var MRT_TableBodyCell = function MRT_TableBodyCell(_ref) {
  var _row$subRows, _row$subRows2;

  var cell = _ref.cell,
      tableInstance = _ref.tableInstance;
  var getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableClickToCopy = _tableInstance$option.enableClickToCopy,
      enableColumnPinning = _tableInstance$option.enableColumnPinning,
      isLoading = _tableInstance$option.isLoading,
      muiTableBodyCellProps = _tableInstance$option.muiTableBodyCellProps,
      muiTableBodyCellSkeletonProps = _tableInstance$option.muiTableBodyCellSkeletonProps,
      onCellClick = _tableInstance$option.onCellClick;

  var _getState = getState(),
      currentEditingRow = _getState.currentEditingRow,
      isDensePadding = _getState.isDensePadding;

  var column = cell.column,
      row = cell.row;
  var mTableCellBodyProps = muiTableBodyCellProps instanceof Function ? muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : muiTableBodyCellProps;
  var mcTableCellBodyProps = column.muiTableBodyCellProps instanceof Function ? column.muiTableBodyCellProps({
    cell: cell,
    tableInstance: tableInstance
  }) : column.muiTableBodyCellProps;

  var tableCellProps = _extends({}, cell.getCellProps(), mTableCellBodyProps, mcTableCellBodyProps);

  var skeletonWidth = useMemo(function () {
    return column.columnDefType === 'display' ? column.getWidth() / 2 : Math.random() * (column.getWidth() - column.getWidth() / 3) + column.getWidth() / 3;
  }, [column.columnDefType, column.getWidth()]);
  return React.createElement(TableCell, Object.assign({
    onClick: function onClick(event) {
      return onCellClick == null ? void 0 : onCellClick({
        event: event,
        cell: cell,
        tableInstance: tableInstance
      });
    }
  }, tableCellProps, {
    sx: _extends({
      p: isDensePadding ? column.columnDefType === 'display' ? '0 0.5rem' : '0.5rem' : column.columnDefType === 'display' ? '0.5rem 0.75rem' : '1rem',
      pl: column.id === 'mrt-expand' ? row.depth + (isDensePadding ? 0.5 : 0.75) + "rem" : undefined,
      transition: 'all 0.2s ease-in-out',
      whiteSpace: isDensePadding || enableColumnPinning && getIsSomeColumnsPinned() ? 'nowrap' : 'normal'
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), isLoading ? React.createElement(Skeleton, Object.assign({
    animation: "wave",
    height: 20,
    width: skeletonWidth
  }, muiTableBodyCellSkeletonProps)) : column.columnDefType === 'display' ? column.Cell == null ? void 0 : column.Cell({
    cell: cell,
    tableInstance: tableInstance
  }) : cell.getIsPlaceholder() || row.getIsGrouped() && column.id !== row.groupingColumnId ? null : cell.getIsAggregated() ? cell.renderAggregatedCell() : column.enableEditing && (currentEditingRow == null ? void 0 : currentEditingRow.id) === row.id ? React.createElement(MRT_EditCellTextField, {
    cell: cell,
    tableInstance: tableInstance
  }) : (enableClickToCopy || column.enableClickToCopy) && column.enableClickToCopy !== false ? React.createElement(React.Fragment, null, React.createElement(MRT_CopyButton, {
    cell: cell,
    tableInstance: tableInstance
  }, cell.renderCell()), row.getIsGrouped() && React.createElement(React.Fragment, null, " (", (_row$subRows = row.subRows) == null ? void 0 : _row$subRows.length, ")")) : React.createElement(React.Fragment, null, cell.renderCell(), row.getIsGrouped() && React.createElement(React.Fragment, null, " (", (_row$subRows2 = row.subRows) == null ? void 0 : _row$subRows2.length, ")")));
};

var MRT_TableDetailPanel = function MRT_TableDetailPanel(_ref) {
  var row = _ref.row,
      tableInstance = _ref.tableInstance;
  var getVisibleFlatColumns = tableInstance.getVisibleFlatColumns,
      _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      muiTableDetailPanelProps = _tableInstance$option.muiTableDetailPanelProps,
      onDetailPanelClick = _tableInstance$option.onDetailPanelClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var tableRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;
  var tableCellProps = muiTableDetailPanelProps instanceof Function ? muiTableDetailPanelProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableDetailPanelProps;
  return React.createElement(TableRow, Object.assign({}, tableRowProps), React.createElement(TableCell, Object.assign({
    colSpan: getVisibleFlatColumns().length + 10,
    onClick: function onClick(event) {
      return onDetailPanelClick == null ? void 0 : onDetailPanelClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    }
  }, tableCellProps, {
    sx: _extends({
      borderBottom: !row.getIsExpanded() ? 'none' : undefined,
      pb: row.getIsExpanded() ? '1rem' : 0,
      pt: row.getIsExpanded() ? '1rem' : 0,
      transition: 'all 0.2s ease-in-out'
    }, tableCellProps == null ? void 0 : tableCellProps.sx)
  }), React.createElement(Collapse, {
    "in": row.getIsExpanded()
  }, renderDetailPanel == null ? void 0 : renderDetailPanel({
    row: row,
    tableInstance: tableInstance
  }))));
};

var MRT_TableBodyRow = function MRT_TableBodyRow(_ref) {
  var pinned = _ref.pinned,
      row = _ref.row,
      tableInstance = _ref.tableInstance;
  var _tableInstance$option = tableInstance.options,
      muiTableBodyRowProps = _tableInstance$option.muiTableBodyRowProps,
      onRowClick = _tableInstance$option.onRowClick,
      renderDetailPanel = _tableInstance$option.renderDetailPanel;
  var getCenterVisibleCells = row.getCenterVisibleCells,
      getIsGrouped = row.getIsGrouped,
      getIsSelected = row.getIsSelected,
      getLeftVisibleCells = row.getLeftVisibleCells,
      getRightVisibleCells = row.getRightVisibleCells,
      getRowProps = row.getRowProps,
      getVisibleCells = row.getVisibleCells;
  var mTableBodyRowProps = muiTableBodyRowProps instanceof Function ? muiTableBodyRowProps({
    row: row,
    tableInstance: tableInstance
  }) : muiTableBodyRowProps;

  var tableRowProps = _extends({}, getRowProps(), mTableBodyRowProps);

  var getVisibleCellsMap = {
    center: getCenterVisibleCells,
    left: getLeftVisibleCells,
    none: getVisibleCells,
    right: getRightVisibleCells
  };
  return React.createElement(React.Fragment, null, React.createElement(TableRow, Object.assign({
    hover: true,
    onClick: function onClick(event) {
      return onRowClick == null ? void 0 : onRowClick({
        event: event,
        row: row,
        tableInstance: tableInstance
      });
    },
    selected: getIsSelected()
  }, tableRowProps), getVisibleCellsMap[pinned]().map(function (cell) {
    return React.createElement(MRT_TableBodyCell, {
      cell: cell,
      key: cell.getCellProps().key,
      tableInstance: tableInstance
    });
  })), renderDetailPanel && !getIsGrouped() && React.createElement(MRT_TableDetailPanel, {
    row: row,
    tableInstance: tableInstance
  }));
};

var MRT_TableBody = function MRT_TableBody(_ref) {
  var pinned = _ref.pinned,
      tableInstance = _ref.tableInstance;
  var getPaginationRowModel = tableInstance.getPaginationRowModel,
      getPrePaginationRowModel = tableInstance.getPrePaginationRowModel,
      getTableBodyProps = tableInstance.getTableBodyProps,
      _tableInstance$option = tableInstance.options,
      enablePagination = _tableInstance$option.enablePagination,
      muiTableBodyProps = _tableInstance$option.muiTableBodyProps;
  var rows = enablePagination ? getPaginationRowModel().rows : getPrePaginationRowModel().rows;
  var mTableBodyProps = muiTableBodyProps instanceof Function ? muiTableBodyProps({
    tableInstance: tableInstance
  }) : muiTableBodyProps;

  var tableBodyProps = _extends({}, getTableBodyProps(), mTableBodyProps);

  return React.createElement(TableBody, Object.assign({}, tableBodyProps), rows.map(function (row) {
    return React.createElement(MRT_TableBodyRow, {
      key: row.getRowProps().key,
      pinned: pinned,
      row: row,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableFooterCell = function MRT_TableFooterCell(_ref) {
  var _ref2, _column$Footer;

  var footer = _ref.footer,
      tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      muiTableFooterCellProps = _tableInstance$option.muiTableFooterCellProps,
      enableColumnResizing = _tableInstance$option.enableColumnResizing;

  var _getState = getState(),
      isDensePadding = _getState.isDensePadding;

  var column = footer.column;
  var mTableFooterCellProps = muiTableFooterCellProps instanceof Function ? muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : muiTableFooterCellProps;
  var mcTableFooterCellProps = column.muiTableFooterCellProps instanceof Function ? column.muiTableFooterCellProps({
    column: column,
    tableInstance: tableInstance
  }) : column.muiTableFooterCellProps;

  var tableCellProps = _extends({}, footer.getFooterProps(), mTableFooterCellProps, mcTableFooterCellProps);

  return React.createElement(TableCell, Object.assign({
    align: column.columnDefType === 'group' ? 'center' : 'left',
    variant: "head"
  }, tableCellProps, {
    //@ts-ignore
    sx: function sx(theme) {
      return _extends({
        backgroundColor: theme.palette.background["default"],
        backgroundImage: "linear-gradient(" + alpha(theme.palette.common.white, 0.05) + "," + alpha(theme.palette.common.white, 0.05) + ")",
        fontWeight: 'bold',
        p: isDensePadding ? '0.5rem' : '1rem',
        transition: "all " + (enableColumnResizing ? '10ms' : '0.2s') + " ease-in-out",
        verticalAlign: 'text-top'
      }, tableCellProps == null ? void 0 : tableCellProps.sx);
    }
  }), footer.isPlaceholder ? null : (_ref2 = (_column$Footer = column.Footer == null ? void 0 : column.Footer({
    footer: footer,
    tableInstance: tableInstance
  })) != null ? _column$Footer : column.footer) != null ? _ref2 : null);
};

var MRT_TableFooterRow = function MRT_TableFooterRow(_ref) {
  var _footerGroup$headers;

  var footerGroup = _ref.footerGroup,
      tableInstance = _ref.tableInstance;
  var muiTableFooterRowProps = tableInstance.options.muiTableFooterRowProps; // if no content in row, skip row

  if (!((_footerGroup$headers = footerGroup.headers) != null && _footerGroup$headers.some(function (h) {
    return h.column.columnDef.footer || h.column.Footer;
  }))) return null;
  var mTableFooterRowProps = muiTableFooterRowProps instanceof Function ? muiTableFooterRowProps({
    footerGroup: footerGroup,
    tableInstance: tableInstance
  }) : muiTableFooterRowProps;

  var tableRowProps = _extends({}, footerGroup.getFooterGroupProps(), mTableFooterRowProps);

  return React.createElement(TableRow, Object.assign({}, tableRowProps), footerGroup.headers.map(function (footer) {
    return React.createElement(MRT_TableFooterCell, {
      footer: footer,
      key: footer.getFooterProps().key,
      tableInstance: tableInstance
    });
  }));
};

var MRT_TableFooter = function MRT_TableFooter(_ref) {
  var pinned = _ref.pinned,
      tableInstance = _ref.tableInstance;
  var getCenterFooterGroups = tableInstance.getCenterFooterGroups,
      getFooterGroups = tableInstance.getFooterGroups,
      getLeftFooterGroups = tableInstance.getLeftFooterGroups,
      getRightFooterGroups = tableInstance.getRightFooterGroups,
      muiTableFooterProps = tableInstance.options.muiTableFooterProps;
  var tableFooterProps = muiTableFooterProps instanceof Function ? muiTableFooterProps({
    tableInstance: tableInstance
  }) : muiTableFooterProps;
  var getFooterGroupsMap = {
    center: getCenterFooterGroups,
    left: getLeftFooterGroups,
    none: getFooterGroups,
    right: getRightFooterGroups
  };
  return React.createElement(TableFooter, Object.assign({}, tableFooterProps), getFooterGroupsMap[pinned]().map(function (footerGroup) {
    return React.createElement(MRT_TableFooterRow, {
      footerGroup: footerGroup,
      key: footerGroup.getFooterGroupProps().key,
      tableInstance: tableInstance
    });
  }));
};

var MRT_Table = function MRT_Table(_ref) {
  var pinned = _ref.pinned,
      tableInstance = _ref.tableInstance;
  var getTableProps = tableInstance.getTableProps,
      _tableInstance$option = tableInstance.options,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      hideTableFooter = _tableInstance$option.hideTableFooter,
      hideTableHead = _tableInstance$option.hideTableHead,
      muiTableProps = _tableInstance$option.muiTableProps;
  var mTableProps = muiTableProps instanceof Function ? muiTableProps({
    tableInstance: tableInstance
  }) : muiTableProps;

  var tableProps = _extends({}, getTableProps(), mTableProps);

  return React.createElement(Table, Object.assign({
    stickyHeader: enableStickyHeader
  }, tableProps), !hideTableHead && React.createElement(MRT_TableHead, {
    pinned: pinned,
    tableInstance: tableInstance
  }), React.createElement(MRT_TableBody, {
    pinned: pinned,
    tableInstance: tableInstance
  }), !hideTableFooter && React.createElement(MRT_TableFooter, {
    pinned: pinned,
    tableInstance: tableInstance
  }));
};

var commonBoxStyles = function commonBoxStyles(_ref) {
  var pinned = _ref.pinned,
      theme = _ref.theme,
      visible = _ref.visible;
  return {
    display: 'grid',
    minWidth: visible ? '200px' : 0,
    overflowX: 'auto',
    boxShadow: pinned === 'left' ? "0 1px 12px " + alpha(theme.palette.common.black, 0.5) : pinned === 'right' ? "0 -1px 12px " + alpha(theme.palette.common.black, 0.5) : 'none'
  };
};

var MRT_TableContainer = function MRT_TableContainer(_ref2) {
  var tableInstance = _ref2.tableInstance;
  var getCenterTableWidth = tableInstance.getCenterTableWidth,
      getIsSomeColumnsPinned = tableInstance.getIsSomeColumnsPinned,
      getLeftTableWidth = tableInstance.getLeftTableWidth,
      getRightTableWidth = tableInstance.getRightTableWidth,
      getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      enableColumnPinning = _tableInstance$option.enableColumnPinning,
      enableStickyHeader = _tableInstance$option.enableStickyHeader,
      idPrefix = _tableInstance$option.idPrefix,
      muiTableContainerProps = _tableInstance$option.muiTableContainerProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen,
      columnPinning = _getState.columnPinning;

  var _useState = useState(0),
      totalToolbarHeight = _useState[0],
      setTotalToolbarHeight = _useState[1];

  var tableContainerProps = muiTableContainerProps instanceof Function ? muiTableContainerProps({
    tableInstance: tableInstance
  }) : muiTableContainerProps;
  useLayoutEffect(function () {
    var _document$getElementB, _document, _document$getElementB2, _document$getElementB3, _document2, _document2$getElement;

    var topToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB = (_document = document) == null ? void 0 : (_document$getElementB2 = _document.getElementById("mrt-" + idPrefix + "-toolbar-top")) == null ? void 0 : _document$getElementB2.offsetHeight) != null ? _document$getElementB : 0 : 0;
    var bottomToolbarHeight = typeof document !== 'undefined' ? (_document$getElementB3 = (_document2 = document) == null ? void 0 : (_document2$getElement = _document2.getElementById("mrt-" + idPrefix + "-toolbar-bottom")) == null ? void 0 : _document2$getElement.offsetHeight) != null ? _document$getElementB3 : 0 : 0;
    setTotalToolbarHeight(topToolbarHeight + bottomToolbarHeight);
  });
  return React.createElement(TableContainer, Object.assign({}, tableContainerProps, {
    sx: _extends({
      maxWidth: '100%',
      maxHeight: enableStickyHeader ? "clamp(350px, calc(100vh - " + totalToolbarHeight + "px), 2000px)" : undefined,
      overflow: 'auto'
    }, tableContainerProps == null ? void 0 : tableContainerProps.sx),
    style: {
      maxHeight: isFullScreen ? "calc(100vh - " + totalToolbarHeight + "px)" : undefined
    }
  }), enableColumnPinning && getIsSomeColumnsPinned() ? React.createElement(Box, {
    sx: {
      display: 'grid',
      gridTemplateColumns: getLeftTableWidth() + "fr " + getCenterTableWidth() + "fr " + getRightTableWidth() + "fr"
    }
  }, React.createElement(Box, {
    sx: function sx(theme) {
      var _columnPinning$left;

      return commonBoxStyles({
        pinned: 'left',
        theme: theme,
        visible: !!((_columnPinning$left = columnPinning.left) != null && _columnPinning$left.length)
      });
    }
  }, React.createElement(MRT_Table, {
    pinned: "left",
    tableInstance: tableInstance
  })), React.createElement(Box, {
    sx: function sx(theme) {
      return commonBoxStyles({
        theme: theme
      });
    }
  }, React.createElement(MRT_Table, {
    pinned: "center",
    tableInstance: tableInstance
  })), React.createElement(Box, {
    sx: function sx(theme) {
      var _columnPinning$right;

      return commonBoxStyles({
        pinned: 'right',
        theme: theme,
        visible: !!((_columnPinning$right = columnPinning.right) != null && _columnPinning$right.length)
      });
    }
  }, React.createElement(MRT_Table, {
    pinned: "right",
    tableInstance: tableInstance
  }))) : React.createElement(MRT_Table, {
    pinned: "none",
    tableInstance: tableInstance
  }));
};

var MRT_TablePaper = function MRT_TablePaper(_ref) {
  var tableInstance = _ref.tableInstance;
  var getState = tableInstance.getState,
      _tableInstance$option = tableInstance.options,
      hideToolbarBottom = _tableInstance$option.hideToolbarBottom,
      hideToolbarTop = _tableInstance$option.hideToolbarTop,
      muiTablePaperProps = _tableInstance$option.muiTablePaperProps;

  var _getState = getState(),
      isFullScreen = _getState.isFullScreen;

  useEffect(function () {
    if (typeof window !== 'undefined') {
      if (isFullScreen) {
        document.body.style.overflow = 'hidden';
      } else {
        document.body.style.overflow = 'auto';
      }
    }
  }, [isFullScreen]);
  var tablePaperProps = muiTablePaperProps instanceof Function ? muiTablePaperProps({
    tableInstance: tableInstance
  }) : muiTablePaperProps;
  return React.createElement(Paper, Object.assign({
    elevation: 2
  }, tablePaperProps, {
    sx: _extends({
      transition: 'all 0.2s ease-in-out'
    }, tablePaperProps == null ? void 0 : tablePaperProps.sx),
    style: {
      height: isFullScreen ? '100%' : undefined,
      left: isFullScreen ? '0' : undefined,
      margin: isFullScreen ? '0' : undefined,
      maxHeight: isFullScreen ? '100%' : undefined,
      maxWidth: isFullScreen ? '100%' : undefined,
      overflowY: !isFullScreen ? 'hidden' : undefined,
      position: isFullScreen ? 'fixed' : undefined,
      right: isFullScreen ? '0' : undefined,
      top: isFullScreen ? '0' : undefined,
      width: isFullScreen ? '100vw' : undefined,
      zIndex: isFullScreen ? 1200 : 1,
      bottom: isFullScreen ? '0' : undefined
    }
  }), !hideToolbarTop && React.createElement(MRT_ToolbarTop, {
    tableInstance: tableInstance
  }), React.createElement(MRT_TableContainer, {
    tableInstance: tableInstance
  }), !hideToolbarBottom && React.createElement(MRT_ToolbarBottom, {
    tableInstance: tableInstance
  }));
};

var getAllLeafColumnDefs = function getAllLeafColumnDefs(columns) {
  var lowestLevelColumns = columns;
  var currentCols = columns;

  while (!!((_currentCols = currentCols) != null && _currentCols.length) && currentCols.some(function (col) {
    return col.columns;
  })) {
    var _currentCols;

    var nextCols = currentCols.filter(function (col) {
      return !!col.columns;
    }).map(function (col) {
      return col.columns;
    }).flat();

    if (nextCols.every(function (col) {
      return !(col != null && col.columns);
    })) {
      lowestLevelColumns = [].concat(lowestLevelColumns, nextCols);
    }

    currentCols = nextCols;
  }

  return lowestLevelColumns.filter(function (col) {
    return !col.columns;
  });
};
var createGroup = function createGroup(table, column, currentFilterTypes) {
  var _column$columns;

  return table.createGroup(_extends({}, column, {
    columns: column == null ? void 0 : (_column$columns = column.columns) == null ? void 0 : _column$columns.map == null ? void 0 : _column$columns.map(function (col) {
      return col.columns ? createGroup(table, col, currentFilterTypes) : createDataColumn(table, col, currentFilterTypes);
    })
  }));
};
var createDataColumn = function createDataColumn(table, column, currentFilterTypes) {
  return (// @ts-ignore
    table.createDataColumn(column.id, _extends({
      filterType: currentFilterTypes[column.id] || MRT_FILTER_TYPE.BEST_MATCH
    }, column))
  );
};
var createDisplayColumn = function createDisplayColumn(table, column) {
  return table.createDisplayColumn(column);
};

var MRT_TableRoot = function MRT_TableRoot(props) {
  var _props$initialState$i, _props$initialState, _props$initialState$i2, _props$initialState2, _props$initialState$s, _props$initialState3, _props$initialState$s2, _props$initialState4, _props$initialState$p, _props$initialState5, _props$initialState5$, _props$initialState$p2, _props$initialState6, _props$initialState6$, _props$initialState$p3, _props$initialState7, _props$initialState7$, _props$globalFilterTy, _props$getSubRows;

  var idPrefix = useMemo(function () {
    var _props$idPrefix;

    return (_props$idPrefix = props.idPrefix) != null ? _props$idPrefix : Math.random().toString(36).substring(2, 9);
  }, [props.idPrefix]);

  var _useState = useState(null),
      currentEditingRow = _useState[0],
      setCurrentEditingRow = _useState[1];

  var _useState2 = useState((_props$initialState$i = (_props$initialState = props.initialState) == null ? void 0 : _props$initialState.isDensePadding) != null ? _props$initialState$i : false),
      isDensePadding = _useState2[0],
      setIsDensePadding = _useState2[1];

  var _useState3 = useState((_props$initialState$i2 = (_props$initialState2 = props.initialState) == null ? void 0 : _props$initialState2.isFullScreen) != null ? _props$initialState$i2 : false),
      isFullScreen = _useState3[0],
      setIsFullScreen = _useState3[1];

  var _useState4 = useState((_props$initialState$s = (_props$initialState3 = props.initialState) == null ? void 0 : _props$initialState3.showFilters) != null ? _props$initialState$s : false),
      showFilters = _useState4[0],
      setShowFilters = _useState4[1];

  var _useState5 = useState((_props$initialState$s2 = (_props$initialState4 = props.initialState) == null ? void 0 : _props$initialState4.showSearch) != null ? _props$initialState$s2 : false),
      showSearch = _useState5[0],
      setShowSearch = _useState5[1];

  var _useState6 = useState({
    pageIndex: (_props$initialState$p = (_props$initialState5 = props.initialState) == null ? void 0 : (_props$initialState5$ = _props$initialState5.pagination) == null ? void 0 : _props$initialState5$.pageIndex) != null ? _props$initialState$p : 0,
    pageSize: (_props$initialState$p2 = (_props$initialState6 = props.initialState) == null ? void 0 : (_props$initialState6$ = _props$initialState6.pagination) == null ? void 0 : _props$initialState6$.pageSize) != null ? _props$initialState$p2 : 10,
    pageCount: (_props$initialState$p3 = (_props$initialState7 = props.initialState) == null ? void 0 : (_props$initialState7$ = _props$initialState7.pagination) == null ? void 0 : _props$initialState7$.pageCount) != null ? _props$initialState$p3 : -1
  }),
      pagination = _useState6[0],
      setPagination = _useState6[1];

  var _useState7 = useState(function () {
    return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
      var _ref, _c$filter, _props$initialState8, _props$initialState8$, _c$filterSelectOption, _ref2;

      return _ref2 = {}, _ref2[c.id] = (_ref = (_c$filter = c.filter) != null ? _c$filter : props == null ? void 0 : (_props$initialState8 = props.initialState) == null ? void 0 : (_props$initialState8$ = _props$initialState8.columnFilters) == null ? void 0 : _props$initialState8$[c.id]) != null ? _ref : !!((_c$filterSelectOption = c.filterSelectOptions) != null && _c$filterSelectOption.length) ? MRT_FILTER_TYPE.EQUALS : MRT_FILTER_TYPE.BEST_MATCH, _ref2;
    })));
  }),
      currentFilterTypes = _useState7[0],
      setCurrentFilterTypes = _useState7[1];

  var _useState8 = useState((_props$globalFilterTy = props.globalFilterType) != null ? _props$globalFilterTy : MRT_FILTER_TYPE.BEST_MATCH_FIRST),
      currentGlobalFilterType = _useState8[0],
      setCurrentGlobalFilterType = _useState8[1];

  var table = useMemo(function () {
    return createTable();
  }, []);
  var displayColumns = useMemo(function () {
    var _props$localization, _props$localization2, _props$localization3, _props$localization4;

    return [(props.enableRowActions || props.enableRowEditing) && createDisplayColumn(table, {
      Cell: function Cell(_ref3) {
        var cell = _ref3.cell;
        return React.createElement(MRT_ToggleRowActionMenuButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      header: (_props$localization = props.localization) == null ? void 0 : _props$localization.actions,
      id: 'mrt-row-actions',
      maxWidth: 60,
      width: 60
    }), (props.enableExpanded || props.enableGrouping) && createDisplayColumn(table, {
      Cell: function Cell(_ref4) {
        var cell = _ref4.cell;
        return React.createElement(MRT_ExpandButton, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableExpandAll ? React.createElement(MRT_ExpandAllButton, {
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization2 = props.localization) == null ? void 0 : _props$localization2.expand,
      id: 'mrt-expand',
      maxWidth: 40,
      width: 40
    }), props.enableRowSelection && createDisplayColumn(table, {
      Cell: function Cell(_ref5) {
        var cell = _ref5.cell;
        return React.createElement(MRT_SelectCheckbox, {
          row: cell.row,
          tableInstance: tableInstance
        });
      },
      Header: function Header() {
        return props.enableSelectAll ? React.createElement(MRT_SelectCheckbox, {
          selectAll: true,
          tableInstance: tableInstance
        }) : null;
      },
      header: (_props$localization3 = props.localization) == null ? void 0 : _props$localization3.select,
      id: 'mrt-select',
      maxWidth: 40,
      width: 40
    }), props.enableRowNumbers && createDisplayColumn(table, {
      Cell: function Cell(_ref6) {
        var cell = _ref6.cell;
        return cell.row.index + 1;
      },
      Header: function Header() {
        return '#';
      },
      header: (_props$localization4 = props.localization) == null ? void 0 : _props$localization4.rowNumbers,
      id: 'mrt-row-numbers',
      maxWidth: 40,
      width: 40,
      minWidth: 40
    })].filter(Boolean);
  }, [props.enableExpandAll, props.enableExpanded, props.enableRowActions, props.enableRowEditing, props.enableRowNumbers, props.enableRowSelection, props.enableSelectAll, props.localization]);
  var columns = useMemo(function () {
    return table.createColumns([].concat(displayColumns, props.columns.map(function (column) {
      return column.columns ? createGroup(table, column, currentFilterTypes) : createDataColumn(table, column, currentFilterTypes);
    })));
  }, [table, props.columns, currentFilterTypes]);
  var data = useMemo(function () {
    return props.isLoading && !props.data.length ? [].concat(Array(10).fill(null)).map(function (_) {
      return Object.assign.apply(Object, [{}].concat(getAllLeafColumnDefs(props.columns).map(function (c) {
        var _ref7;

        return _ref7 = {}, _ref7[c.id] = null, _ref7;
      })));
    }) : props.data;
  }, [props.data, props.isLoading]); //@ts-ignore

  var tableInstance = useTable(table, _extends({}, props, {
    columnFilterRowsFn: columnFilterRowsFn,
    columns: columns,
    data: data,
    debugAll: false,
    expandRowsFn: expandRowsFn,
    //@ts-ignore
    filterTypes: defaultFilterFNs,
    getSubRows: (_props$getSubRows = props.getSubRows) != null ? _props$getSubRows : function (originalRow) {
      return originalRow.subRows;
    },
    globalFilterRowsFn: globalFilterRowsFn,
    globalFilterType: currentGlobalFilterType,
    groupRowsFn: groupRowsFn,
    idPrefix: idPrefix,
    onPaginationChange: function onPaginationChange(updater) {
      return setPagination(function (old) {
        return functionalUpdate(updater, old);
      });
    },
    paginateRowsFn: paginateRowsFn,
    setCurrentEditingRow: setCurrentEditingRow,
    setCurrentFilterTypes: setCurrentFilterTypes,
    setCurrentGlobalFilterType: setCurrentGlobalFilterType,
    setIsDensePadding: setIsDensePadding,
    setIsFullScreen: setIsFullScreen,
    setShowFilters: setShowFilters,
    setShowSearch: setShowSearch,
    sortRowsFn: sortRowsFn,
    state: _extends({}, props.initialState, {
      currentEditingRow: currentEditingRow,
      currentFilterTypes: currentFilterTypes,
      currentGlobalFilterType: currentGlobalFilterType,
      isDensePadding: isDensePadding,
      isFullScreen: isFullScreen,
      //@ts-ignore
      pagination: pagination,
      showFilters: showFilters,
      showSearch: showSearch
    }, props.state)
  }));
  return React.createElement(MRT_TablePaper, {
    tableInstance: tableInstance
  });
};

var _excluded$5 = ["enableColumnActions", "enableColumnFilters", "enableDensePaddingToggle", "enableExpandAll", "enableFullScreenToggle", "enableGlobalFilter", "enableHiding", "enablePagination", "enableSelectAll", "enableSorting", "enableStickyHeader", "icons", "localization", "positionActionsColumn", "positionPagination", "positionToolbarActions", "positionToolbarAlertBanner"];

window.performance = window.performance || {
  now: function now() {
    return new Date().getTime();
  }
};
var MaterialReactTable = (function (_ref) {
  var _ref$enableColumnActi = _ref.enableColumnActions,
      enableColumnActions = _ref$enableColumnActi === void 0 ? true : _ref$enableColumnActi,
      _ref$enableColumnFilt = _ref.enableColumnFilters,
      enableColumnFilters = _ref$enableColumnFilt === void 0 ? true : _ref$enableColumnFilt,
      _ref$enableDensePaddi = _ref.enableDensePaddingToggle,
      enableDensePaddingToggle = _ref$enableDensePaddi === void 0 ? true : _ref$enableDensePaddi,
      _ref$enableExpandAll = _ref.enableExpandAll,
      enableExpandAll = _ref$enableExpandAll === void 0 ? true : _ref$enableExpandAll,
      _ref$enableFullScreen = _ref.enableFullScreenToggle,
      enableFullScreenToggle = _ref$enableFullScreen === void 0 ? true : _ref$enableFullScreen,
      _ref$enableGlobalFilt = _ref.enableGlobalFilter,
      enableGlobalFilter = _ref$enableGlobalFilt === void 0 ? true : _ref$enableGlobalFilt,
      _ref$enableHiding = _ref.enableHiding,
      enableHiding = _ref$enableHiding === void 0 ? true : _ref$enableHiding,
      _ref$enablePagination = _ref.enablePagination,
      enablePagination = _ref$enablePagination === void 0 ? true : _ref$enablePagination,
      _ref$enableSelectAll = _ref.enableSelectAll,
      enableSelectAll = _ref$enableSelectAll === void 0 ? true : _ref$enableSelectAll,
      _ref$enableSorting = _ref.enableSorting,
      enableSorting = _ref$enableSorting === void 0 ? true : _ref$enableSorting,
      _ref$enableStickyHead = _ref.enableStickyHeader,
      enableStickyHeader = _ref$enableStickyHead === void 0 ? true : _ref$enableStickyHead,
      icons = _ref.icons,
      localization = _ref.localization,
      _ref$positionActionsC = _ref.positionActionsColumn,
      positionActionsColumn = _ref$positionActionsC === void 0 ? 'first' : _ref$positionActionsC,
      _ref$positionPaginati = _ref.positionPagination,
      positionPagination = _ref$positionPaginati === void 0 ? 'bottom' : _ref$positionPaginati,
      _ref$positionToolbarA = _ref.positionToolbarActions,
      positionToolbarActions = _ref$positionToolbarA === void 0 ? 'top' : _ref$positionToolbarA,
      _ref$positionToolbarA2 = _ref.positionToolbarAlertBanner,
      positionToolbarAlertBanner = _ref$positionToolbarA2 === void 0 ? 'top' : _ref$positionToolbarA2,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded$5);

  return React.createElement(MRT_TableRoot, Object.assign({
    enableColumnActions: enableColumnActions,
    enableColumnFilters: enableColumnFilters,
    enableDensePaddingToggle: enableDensePaddingToggle,
    enableExpandAll: enableExpandAll,
    enableFullScreenToggle: enableFullScreenToggle,
    enableGlobalFilter: enableGlobalFilter,
    enableHiding: enableHiding,
    enablePagination: enablePagination,
    enableSelectAll: enableSelectAll,
    enableSorting: enableSorting,
    enableStickyHeader: enableStickyHeader,
    icons: _extends({}, MRT_Default_Icons, icons),
    localization: _extends({}, MRT_DefaultLocalization_EN, localization),
    positionActionsColumn: positionActionsColumn,
    positionPagination: positionPagination,
    positionToolbarActions: positionToolbarActions,
    positionToolbarAlertBanner: positionToolbarAlertBanner
  }, rest));
});

export default MaterialReactTable;
//# sourceMappingURL=material-react-table.esm.js.map
